@@ -175,14 +175,9 @@ MsRunAlignmentGroup::prepareMsrunRetentionTimesForAlignment() const
 }
 
 void
-MsRunAlignmentGroup::savePostMassChroqmlParameters(
-  MasschroqFileParameters file_parameters,
-  ZivyParams zivy_params,
-  QString masschroqml_file)
+MsRunAlignmentGroup::savePostMassChroqmlParameters(QString masschroqml_file)
 {
-  m_masschroqFileParameters = file_parameters;
-  m_zivyParams              = zivy_params;
-  m_masschroqmlPath         = masschroqml_file;
+  m_masschroqmlPath = masschroqml_file;
 }
 
 void
@@ -203,11 +198,6 @@ MsRunAlignmentGroup::getGroupStatus()
   return m_status;
 }
 
-MasschroqFileParameters
-MsRunAlignmentGroup::getMassChroQFileParams()
-{
-  return m_masschroqFileParameters;
-}
 
 QString
 MsRunAlignmentGroup::getMassChroqmlPath()
@@ -215,17 +205,6 @@ MsRunAlignmentGroup::getMassChroqmlPath()
   return m_masschroqmlPath;
 }
 
-ZivyParams
-MsRunAlignmentGroup::getZivyParams()
-{
-  return m_zivyParams;
-}
-
-void
-MsRunAlignmentGroup::setMassChroQFileParams(MasschroqFileParameters mcq_params)
-{
-  m_masschroqFileParameters = mcq_params;
-}
 
 void
 MsRunAlignmentGroup::setMassChroqmlPath(QString masschroqml_path)
@@ -233,11 +212,6 @@ MsRunAlignmentGroup::setMassChroqmlPath(QString masschroqml_path)
   m_masschroqmlPath = masschroqml_path;
 }
 
-void
-MsRunAlignmentGroup::setZivyParams(ZivyParams zivy_params)
-{
-  m_zivyParams = zivy_params;
-}
 
 QString
 MsRunAlignmentGroup::getMassChroqmlRdataPath() const
