@@ -25,9 +25,8 @@
 #include <QDebug>
 #include <memory>
 #include "msrun.h"
-// #include "project.h"
-#include "../gui/masschroq_run_dialog/masschroqfileparameters.h"
 #include "../gui/xic_view/xic_widgets/zivywidget.h"
+#include "masschroq_run/masschroqfileparameters.h"
 
 enum class AlignmentGroupStatus : std::int8_t
 {
@@ -61,17 +60,11 @@ class MsRunAlignmentGroup
   void removeMsRunFromMsRunAlignmentGroupList(MsRunSp removed_msrun);
   void prepareMsrunRetentionTimesForAlignment() const;
 
-  void savePostMassChroqmlParameters(MasschroqFileParameters file_parameters,
-                                     ZivyParams zivy_params,
-                                     QString masschroqml_file);
+  void savePostMassChroqmlParameters(QString masschroqml_file);
   void setMassChroQRunStatus(AlignmentGroupStatus status);
   void setMassChroQRunStatusFromInt(int status);
   AlignmentGroupStatus getGroupStatus();
-  MasschroqFileParameters getMassChroQFileParams();
-  ZivyParams getZivyParams();
   QString getMassChroqmlPath();
-  void setMassChroQFileParams(MasschroqFileParameters mcq_params);
-  void setZivyParams(ZivyParams zivy_params);
   void setMassChroqmlPath(QString masschroqml_path);
 
   QString getMassChroqmlRdataPath() const;
@@ -85,7 +78,6 @@ class MsRunAlignmentGroup
 
   // Post MassChroQ run params
   AlignmentGroupStatus m_status;
-  MasschroqFileParameters m_masschroqFileParameters;
-  ZivyParams m_zivyParams;
+  MasschroqFileParametersSp msp_masschroqFileParametersSp;
   QString m_masschroqmlPath;
 };
