@@ -29,11 +29,9 @@
 #include <QThread>
 #include <pappsomspp/pappsoexception.h>
 #include <pappsomspp/exception/exceptioninterrupted.h>
-#include "condorqxmlsaxhandler.h"
 
 CondorProcess::CondorProcess(MainWindow *p_main_window,
-                             WorkMonitorInterface *p_monitor,
-                             QString app_run)
+                             WorkMonitorInterface *p_monitor, QString app_run)
 {
   mp_main_window = p_main_window;
   mp_monitor     = p_monitor;
@@ -113,6 +111,7 @@ CondorProcess::parseCondorJobNumber(QString condor_job)
     {
       m_condorClusterNumber = txt_submit.cap(2).toUInt();
       m_condorJobSize       = txt_submit.cap(1).toUInt();
+      m_condoQueueParser.setCondorJobSize(m_condorJobSize);
     }
   else
     {
@@ -132,6 +131,7 @@ CondorProcess::surveyCondorJob()
     {
       QThread::msleep(m_condorStatusTimerMillisecond);
       getCondorJobState();
+      displayCondorJobStatus();
       mp_monitor->message(
         QObject::tr(
           "%1 is running in condor cluster %2\n%3 on %4 jobs completed")
@@ -170,8 +170,12 @@ CondorProcess::getCondorJobState()
 
       if(!condor_q_process.waitForStarted())
         {
-          throw pappso::PappsoException(
-            QObject::tr("HTCondor condor_q process failed to start"));
+          QString err = QObject::tr("Could not start condor_q process "
+                                    "'%1' with arguments '%2': %3")
+                          .arg(m_condorQCommand)
+                          .arg(arguments.join(QStringLiteral(" ")))
+                          .arg(condor_q_process.errorString());
+          throw pappso::PappsoException(err);
         }
 
       if(!condor_q_process.waitForFinished(m_maxTimeMs))
@@ -229,8 +233,12 @@ CondorProcess::condorRemoveJob()
 
       if(!condor_rm_process.waitForStarted())
         {
-          throw pappso::PappsoException(
-            QObject::tr("HTCondor condor_rm process failed to start"));
+          QString err = QObject::tr("Could not start condor_rm process "
+                                    "'%1' with arguments '%2': %3")
+                          .arg(m_condorQCommand)
+                          .arg(arguments.join(QStringLiteral(" ")))
+                          .arg(condor_rm_process.errorString());
+          throw pappso::PappsoException(err);
         }
 
       if(!condor_rm_process.waitForFinished(m_maxTimeMs))
@@ -278,30 +286,19 @@ CondorProcess::parseCondorQueue(QString &condor_q_xml)
 {
   try
     {
-      CondorQxmlSaxHandler *parser = new CondorQxmlSaxHandler(this);
 
-      QXmlSimpleReader simplereader;
-      simplereader.setContentHandler(parser);
-      simplereader.setErrorHandler(parser);
-
-      qDebug() << " Read condor_q_xml";
-
-      QXmlInputSource xml_input_source;
-      xml_input_source.setData(condor_q_xml);
-
-      if(simplereader.parse(xml_input_source))
+      if(m_condoQueueParser.read(condor_q_xml))
         {
+          m_condorCompletedJobs =
+            m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Completed);
         }
       else
         {
-          qDebug() << parser->errorString();
-
           throw pappso::PappsoException(
             QObject::tr("Error reading condor_q xml string :\n %1\n%2")
-              .arg(parser->errorString())
+              .arg(m_condoQueueParser.errorString())
               .arg(condor_q_xml));
         }
-      delete parser;
     }
   catch(pappso::PappsoException &exception_pappso)
     {
@@ -324,21 +321,19 @@ CondorProcess::getCondorJobSize() const
 }
 
 void
-CondorProcess::setCondorJobStatus(std::int8_t count_status[10])
+CondorProcess::displayCondorJobStatus() const
 {
   QString status_message =
-    QString(
-      "%1 unexpanded jobs\n%2 idle jobs\n%3 running jobs\n%4 removed "
-      "jobs\n%5 completed jobs\n%6 held jobs\n%7 submission errors")
-      .arg(count_status[0])
-      .arg(count_status[1])
-      .arg(count_status[2])
-      .arg(count_status[3])
-      .arg(count_status[4])
-      .arg(count_status[5])
-      .arg(count_status[6]);
+    QString("%1 unexpanded jobs\n%2 idle jobs\n%3 running jobs\n%4 removed "
+            "jobs\n%5 completed jobs\n%6 held jobs\n%7 submission errors")
+      .arg(m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Unexpanded))
+      .arg(m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Idle))
+      .arg(m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Running))
+      .arg(m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Removed))
+      .arg(m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Completed))
+      .arg(m_condoQueueParser.countCondorJobStatus(CondorJobStatus::Held))
+      .arg(m_condoQueueParser.countCondorJobStatus(
+        CondorJobStatus::Submission_err));
 
   mp_monitor->setText(status_message);
-
-  m_condorCompletedJobs = count_status[(std::int8_t)CondorJobStatus::Completed];
 }
