@@ -39,7 +39,7 @@ IdentificationDataSource::IdentificationDataSource(const QString resource_name)
 IdentificationDataSource::IdentificationDataSource(
   const IdentificationDataSource &other)
 {
-  _ms_run_sp      = other._ms_run_sp;
+  msp_msRun       = other.msp_msRun;
   _resource_name  = other._resource_name;
   _xml_id         = other._xml_id;
   _version        = other._version;
@@ -97,35 +97,37 @@ IdentificationDataSource::getResourceName() const
 const QString
 IdentificationDataSource::getSampleName() const
 {
-  return _ms_run_sp.get()->getSampleName();
+  return msp_msRun.get()->getSampleName();
 }
 
 void
 IdentificationDataSource::setMsRunSp(MsRunSp ms_run_sp)
 {
-  _ms_run_sp = ms_run_sp;
+  msp_msRun = ms_run_sp;
 }
 MsRunSp
 IdentificationDataSource::getMsRunSp() const
 {
-  return (_ms_run_sp);
+  return (msp_msRun);
 }
 void
 IdentificationDataSource::setIdentificationEngine(IdentificationEngine engine)
 {
-  _engine = engine;
+  m_identificationEngine = engine;
 }
 
 IdentificationEngine
 IdentificationDataSource::getIdentificationEngine() const
 {
-  return _engine;
+  return m_identificationEngine;
 }
 const QString
 IdentificationDataSource::getIdentificationEngineName() const
 {
+
+  // qDebug();
   QString name = "unknown";
-  switch(_engine)
+  switch(m_identificationEngine)
     {
       case IdentificationEngine::XTandem:
         name = "X!Tandem";
@@ -152,9 +154,14 @@ IdentificationDataSource::getIdentificationEngineName() const
       case IdentificationEngine::MSGFplus:
         name = "MS-GF+";
         break;
+      case IdentificationEngine::DeepProt:
+        name = "DeepProt";
+        break;
       default:
         break;
     }
+
+  // qDebug();
   return name;
 }
 const QString &
@@ -209,64 +216,19 @@ IdentificationDataSource::getIdentificationEngineStatistics(
     }
 }
 
-pappso::MassSpectrumCstSPtr
-IdentificationDataSource::getMassSpectrumCstSPtr(unsigned int scan_number) const
-{
-
-  qDebug() << "scan=" << scan_number;
-  if(_ms_run_sp.get()->getMzFormat() == pappso::MzFormat::MGF)
-    {
-      scan_number = scan_number - 1;
-      qDebug() << "MGF format";
-    }
-  pappso::MsRunReaderSPtr msrun_reader_sp =
-    _ms_run_sp.get()->getMsRunReaderSPtr();
-
-  if(msrun_reader_sp == nullptr)
-    {
-      msrun_reader_sp = _ms_run_sp.get()->findMsRunFile();
-      if(msrun_reader_sp == nullptr)
-        {
-          throw pappso::ExceptionNotFound(
-            QObject::tr("mz data \"%1\" file not found")
-              .arg(_ms_run_sp.get()->getFileName()));
-        }
-    }
-  qDebug();
-  msrun_reader_sp = _ms_run_sp.get()->getMsRunReaderSPtr();
-  if(msrun_reader_sp == nullptr)
-    {
-      throw pappso::ExceptionNotFound(
-        QObject::tr("mz data \"%1\" file not found")
-          .arg(_ms_run_sp.get()->getFileName()));
-    }
-
-
-  // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__  <<
-  // _ms_run_sp.get()->getMsRunReaderSp().get()->getSpectrumListSize();
-
-
-  std::size_t spectrum_index = scan_number;
-  qDebug();
-  if(msrun_reader_sp.get()->hasScanNumbers())
-    {
-      qDebug() << "HAS SCAN NUMBERS";
-      spectrum_index =
-        msrun_reader_sp.get()->scanNumber2SpectrumIndex(scan_number);
-    }
-  qDebug() << " spectrum file="
-           << msrun_reader_sp.get()->getMsRunId().get()->getFileName()
-           << " index=" << spectrum_index;
-  pappso::MassSpectrumCstSPtr spectrum_sp =
-    msrun_reader_sp.get()->massSpectrumCstSPtr(spectrum_index);
-  qDebug();
-  return spectrum_sp;
-}
-
 void
 IdentificationDataSource::addFastaFile(FastaFileSp file)
 {
-  _fastafile_list.push_back(file);
+  // unicity check
+  if(std::find_if(_fastafile_list.begin(),
+                  _fastafile_list.end(),
+                  [file](FastaFileSp &fasta_file_sp) {
+                    return fasta_file_sp.get() == file.get();
+                  }) == _fastafile_list.end())
+    {
+
+      _fastafile_list.push_back(file);
+    }
 }
 const std::vector<FastaFileSp> &
 IdentificationDataSource::getFastaFileList() const
@@ -279,9 +241,9 @@ IdentificationDataSource::isValid(
   const PeptideEvidence *p_peptide_evidence,
   const AutomaticFilterParameters &automatic_filter_parameters) const
 {
-
   if(automatic_filter_parameters.useFDR())
     {
+      qDebug() << "useFDR";
       QVariant qvalue =
         p_peptide_evidence->getParam(PeptideEvidenceParam::pappso_qvalue);
       if(qvalue.isNull())
@@ -292,8 +254,10 @@ IdentificationDataSource::isValid(
               .arg(getIdentificationEngineName())
               .arg(p_peptide_evidence->getPeptideXtpSp().get()->getSequence()));
         }
+      qDebug() << qvalue.toDouble();
       if(qvalue.toDouble() < automatic_filter_parameters.getFilterPeptideFDR())
         {
+          qDebug();
           return true;
         }
     }
@@ -302,8 +266,10 @@ IdentificationDataSource::isValid(
       if(p_peptide_evidence->getEvalue() <=
          automatic_filter_parameters.getFilterPeptideEvalue())
         {
+          // qDebug();
           return true;
         }
     }
+  // qDebug();
   return false;
 }
