@@ -24,6 +24,7 @@
 #include "identificationxtandemfile.h"
 #include <pappsomspp/pappsoexception.h>
 #include "../project.h"
+#include "../../input/tandem/tandeminfoparser.h"
 #include "../../input/xtandemsaxhandler.h"
 
 IdentificationXtandemFile::IdentificationXtandemFile(
@@ -52,10 +53,22 @@ IdentificationXtandemFile::parseTo(Project *p_project)
 
   qDebug() << "Read X!Tandem XML result file '"
            << _xtandem_file.absoluteFilePath() << "'";
+  TandemInfoParser tandem_info_parser;
 
-  MsRunSp msrun_sp =
-    p_project->getMsRunStore().getInstance(QFileInfo(_xtandem_file).baseName());
+  if(!tandem_info_parser.readFile(_xtandem_file.absoluteFilePath()))
+    {
+
+      throw pappso::PappsoException(
+        QObject::tr("Error reading %1 X!Tandem file :\n %2")
+          .arg(_xtandem_file.absoluteFilePath())
+          .arg(tandem_info_parser.errorString()));
+    }
+
+  MsRunSp msrun_sp = p_project->getMsRunStore().getInstance(
+    tandem_info_parser.getSpectraDataLocation());
+  msrun_sp.get()->setMzFormat(tandem_info_parser.getMzFormat());
   setMsRunSp(msrun_sp);
+
   std::vector<IdentificationGroup *> identification_list =
     p_project->getIdentificationGroupList();
   IdentificationGroup *identification_group_p = nullptr;
@@ -113,7 +126,7 @@ IdentificationXtandemFile::parseTo(Project *p_project)
       qfile.close();
 
       throw pappso::PappsoException(
-        QObject::tr("Error reading %1 XPIP file :\n %2")
+        QObject::tr("Error reading %1 X!Tandem file :\n %2")
           .arg(_xtandem_file.absoluteFilePath())
           .arg(parser->errorString()));
     }
