@@ -30,8 +30,7 @@
 #include <pappsomspp/exception/exceptioninterrupted.h>
 
 MassChroQBatchProcess::MassChroQBatchProcess(
-  MainWindow *p_main_window,
-  WorkMonitorInterface *p_monitor,
+  MainWindow *p_main_window, WorkMonitorInterface *p_monitor,
   const MassChroQRunBatch masschroq_batch_param)
 {
   mp_mainWindow       = p_main_window;
@@ -87,13 +86,9 @@ MassChroQBatchProcess::run()
 
 
   qDebug();
-  connect(mpa_mcqProcess,
-          &QProcess::readyReadStandardOutput,
-          this,
+  connect(mpa_mcqProcess, &QProcess::readyReadStandardOutput, this,
           &MassChroQBatchProcess::readyReadStandardOutput);
-  connect(mpa_mcqProcess,
-          &QProcess::readyReadStandardError,
-          this,
+  connect(mpa_mcqProcess, &QProcess::readyReadStandardError, this,
           &MassChroQBatchProcess::readyReadStandardError);
 
   qDebug();
@@ -102,8 +97,12 @@ MassChroQBatchProcess::run()
   qDebug();
   if(!mpa_mcqProcess->waitForStarted())
     {
-      throw pappso::PappsoException(
-        QObject::tr("MassChroQ process failed to start"));
+      QString err = QObject::tr("Could not start MassChroQ process "
+                                "'%1' with arguments '%2': %3")
+                      .arg(masschroq_path)
+                      .arg(arguments.join(QStringLiteral(" ")))
+                      .arg(mpa_mcqProcess->errorString());
+      throw pappso::PappsoException(err);
     }
 
   qDebug();
@@ -214,8 +213,12 @@ MassChroQBatchProcess::checkMassChroQMLValidity()
 
   if(!mcq_process->waitForStarted())
     {
-      throw pappso::PappsoException(
-        QObject::tr("MassChroQ process failed to start"));
+      QString err = QObject::tr("Could not start MassChroQ process "
+                                "'%1' with arguments '%2': %3")
+                      .arg(masschroq_path)
+                      .arg(arguments.join(QStringLiteral(" ")))
+                      .arg(mpa_mcqProcess->errorString());
+      throw pappso::PappsoException(err);
     }
 
   while(mcq_process->waitForFinished(1000) == false)
