@@ -41,7 +41,6 @@
 #include <pappsomspp/msfile/msfileaccessor.h>
 #include <pappsomspp/exception/exceptionnotimplemented.h>
 #include <pappsomspp/msrun/private/timsmsrunreaderms2.h>
-#include <pappsomspp/processing/filters/filterpseudocentroid.h>
 #include <pappsomspp/processing/filters/filterchargedeconvolution.h>
 #include <pappsomspp/processing/filters/filtertriangle.h>
 #include <pappsomspp/precision.h>
@@ -91,6 +90,7 @@ MsRun::buildMsRunReaderSp()
 
       p_accessor->setPreferedFileReaderType(pappso::MzFormat::brukerTims,
                                             pappso::FileReaderType::tims_ms2);
+      this->setMzFormat(p_accessor->getFileFormat());
     }
   catch(pappso::ExceptionNotFound &error)
     {
@@ -478,7 +478,7 @@ MsRun::computeMsRunRetentionTime()
     {
       qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__
                << " msrun id=" << getXmlId();
-      mpa_msrunRetentionTime->computePeptideRetentionTimes();
+      mpa_msrunRetentionTime->computeSeamarks();
     }
 }
 
