@@ -29,6 +29,9 @@
 
 Project::Project()
 {
+  msp_masschroqFileParametersSp = std::make_shared<MasschroqFileParameters>();
+  msp_masschroqFileParametersSp.get()->load();
+  msp_masschroqFileParametersSp.get()->m_zivyParams.loadSettings();
 }
 
 Project::~Project()
@@ -544,3 +547,9 @@ Project::isTarget(PeptideEvidence *p_pe) const
     }
   return false;
 }
+
+const MasschroqFileParametersSp &
+Project::getMasschroqFileParametersSp() const
+{
+  return msp_masschroqFileParametersSp;
+}
