@@ -38,6 +38,7 @@
 #include "labeling/labelingmethod.h"
 #include "alignmentgroup.h"
 #include "mcqr/mcqrexperiment.h"
+#include "masschroq_run/masschroqfileparameters.h"
 
 class Project;
 typedef std::shared_ptr<Project> ProjectSp;
@@ -239,6 +240,10 @@ class Project
    */
   bool isTarget(PeptideEvidence *p_pe) const;
 
+  /** @brief get MassChroQ parameters specific to this project
+   */
+  const MasschroqFileParametersSp &getMasschroqFileParametersSp() const;
+
   private:
   LabelingMethodSp _labeling_method_sp;
   ProjectMode _project_mode = ProjectMode::combined;
@@ -263,4 +268,5 @@ class Project
   MsRunStore _msrun_store;
   FastaFileStore _fasta_file_store;
   bool m_project_changed = false;
+  MasschroqFileParametersSp msp_masschroqFileParametersSp;
 };
