@@ -364,7 +364,7 @@ ProteinMatch::countSequenceLi(ValidationState state,
                               const Label *p_label) const
 {
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
-  std::set<QString> sequence_list;
+  std::vector<QString> sequence_list;
   for(auto &peptide_match : _peptide_match_list)
     {
       if(peptide_match.getPeptideEvidence()->getValidationState() >= state)
@@ -381,10 +381,11 @@ ProteinMatch::countSequenceLi(ValidationState state,
                         .get()
                         ->getLabel() == p_label))
                     {
-                      sequence_list.insert(peptide_match.getPeptideEvidence()
-                                             ->getPeptideXtpSp()
-                                             .get()
-                                             ->getSequenceLi());
+                      sequence_list.push_back(
+                        peptide_match.getPeptideEvidence()
+                          ->getPeptideXtpSp()
+                          .get()
+                          ->getSequenceLi());
                     }
                 }
               else
@@ -393,27 +394,31 @@ ProteinMatch::countSequenceLi(ValidationState state,
                   if(peptide_match.getPeptideEvidence()->getMsRunP() ==
                      p_msrun_id)
                     {
-                      sequence_list.insert(peptide_match.getPeptideEvidence()
-                                             ->getPeptideXtpSp()
-                                             .get()
-                                             ->getSequenceLi());
+                      sequence_list.push_back(
+                        peptide_match.getPeptideEvidence()
+                          ->getPeptideXtpSp()
+                          .get()
+                          ->getSequenceLi());
                     }
                 }
             }
           else
             {
               // overall samples
-              sequence_list.insert(peptide_match.getPeptideEvidence()
-                                     ->getPeptideXtpSp()
-                                     .get()
-                                     ->getSequenceLi());
+              sequence_list.push_back(peptide_match.getPeptideEvidence()
+                                        ->getPeptideXtpSp()
+                                        .get()
+                                        ->getSequenceLi());
             }
         }
     }
+
+  std::sort(sequence_list.begin(), sequence_list.end());
+  auto last = std::unique(sequence_list.begin(), sequence_list.end());
   // qDebug() <<"ProteinMatch::countValidAndCheckedPeptide end " <<
   // sequence_list.size(); qDebug() << __FILE__ << " " << __FUNCTION__ << " " <<
   // __LINE__;
-  return sequence_list.size();
+  return std::distance(sequence_list.begin(), last);
 }
 
 std::size_t
@@ -436,7 +441,7 @@ ProteinMatch::countPeptideMassCharge(ValidationState state,
                                      const MsRun *sp_msrun_id,
                                      const Label *p_label) const
 {
-  std::set<QString> sequence_list;
+  std::vector<QString> sequence_list;
   for(auto &peptide_match : _peptide_match_list)
     {
       if(peptide_match.getPeptideEvidence()->getValidationState() >= state)
@@ -453,7 +458,7 @@ ProteinMatch::countPeptideMassCharge(ValidationState state,
                            .get()
                            ->getLabel() == p_label)
                         {
-                          sequence_list.insert(
+                          sequence_list.push_back(
                             QString("%1-%2-%3")
                               .arg(peptide_match.getPeptideEvidence()
                                      ->getPeptideXtpSp()
@@ -471,7 +476,7 @@ ProteinMatch::countPeptideMassCharge(ValidationState state,
                     }
                   else
                     {
-                      sequence_list.insert(
+                      sequence_list.push_back(
                         QString("%1-%2-%3")
                           .arg(peptide_match.getPeptideEvidence()
                                  ->getPeptideXtpSp()
@@ -491,7 +496,7 @@ ProteinMatch::countPeptideMassCharge(ValidationState state,
           else
             {
               // overall samples
-              sequence_list.insert(
+              sequence_list.push_back(
                 QString("%1-%2-%3")
                   .arg(peptide_match.getPeptideEvidence()
                          ->getPeptideXtpSp()
@@ -507,7 +512,10 @@ ProteinMatch::countPeptideMassCharge(ValidationState state,
             }
         }
     }
-  return sequence_list.size();
+
+  std::sort(sequence_list.begin(), sequence_list.end());
+  auto last = std::unique(sequence_list.begin(), sequence_list.end());
+  return std::distance(sequence_list.begin(), last);
 }
 
 pappso::pappso_double
@@ -652,9 +660,18 @@ ProteinMatch::getHtmlSequence(PeptideEvidence *peptide_evidence_to_locate) const
   // qDebug() << "ProteinMatch::getCoverage begin prot_size=" << prot_size << "
   // " << _protein_sp.get()-//>getSequence();
   if(prot_size == 0)
-    return 0;
-  bool cover_bool[prot_size]     = {false};
-  bool highlight_bool[prot_size] = {false};
+    {
+      return 0;
+    }
+
+  bool cover_bool[prot_size];
+  bool highlight_bool[prot_size];
+  for(size_t i = 0; i < prot_size; i++)
+    {
+      cover_bool[i]     = false;
+      highlight_bool[i] = false;
+    }
+
   for(auto &peptide_match : _peptide_match_list)
     {
       if(peptide_match.getPeptideEvidence() == peptide_evidence_to_locate)
@@ -751,7 +768,13 @@ ProteinMatch::getCoverage() const
   // " << _protein_sp.get()-//>getSequence();
   if(prot_size == 0)
     return 0;
-  bool cover_bool[prot_size] = {false};
+
+  bool cover_bool[prot_size];
+  for(size_t i = 0; i < prot_size; i++)
+    {
+      cover_bool[i] = false;
+    }
+
   for(auto &peptide_match : _peptide_match_list)
     {
       if(peptide_match.getPeptideEvidence()->isValidAndChecked())
@@ -784,25 +807,25 @@ ProteinMatch::getGroupingGroupSp() const
 void
 ProteinMatch::setGroupInstance(GroupStore &group_store)
 {
-  qDebug();
+  // qDebug();
   _sp_group = nullptr;
   if(_sp_grp_protein != nullptr)
     {
       unsigned int group_number = _sp_grp_protein.get()->getGroupNumber();
-      qDebug() << "group_number=" << group_number;
+      // qDebug() << "group_number=" << group_number;
       if(group_number > 0)
         {
           _sp_group = group_store.getInstance(group_number);
           _sp_group.get()->add(this);
         }
     }
-  qDebug();
+  // qDebug();
 }
 
 
 void
 ProteinMatch::collectPeptideEvidences(
-  std::set<const PeptideEvidence *> &peptide_evidence_set,
+  std::vector<const PeptideEvidence *> &peptide_evidence_set,
   ValidationState state) const
 {
   for(auto &peptide_match : _peptide_match_list)
@@ -811,7 +834,7 @@ ProteinMatch::collectPeptideEvidences(
         peptide_match.getPeptideEvidence();
       if(p_peptide_evidence->getValidationState() >= state)
         {
-          peptide_evidence_set.insert(p_peptide_evidence);
+          peptide_evidence_set.push_back(p_peptide_evidence);
         }
     }
 }
@@ -860,3 +883,17 @@ ProteinMatch::getFlankingCterRegion(const PeptideMatch &peptide_match,
 
   return flanking;
 }
+
+bool
+ProteinMatch::contains(const PeptideEvidence *p_pe) const
+{
+
+  for(auto &peptide_match : _peptide_match_list)
+    {
+      if(p_pe == peptide_match.getPeptideEvidence())
+        {
+          return true;
+        }
+    }
+  return false;
+}
