@@ -22,8 +22,7 @@
  *implementation
  ******************************************************************************/
 
-#ifndef FASTAFILE_H
-#define FASTAFILE_H
+#pragma once
 
 #include <QFileInfo>
 #include <memory>
@@ -52,16 +51,18 @@ class FastaFile
    * */
   void setDecoys(ProteinStore &protein_store) const;
 
+  /** @brief sets the fasta filename
+   */
+  void setFastaSource(const QString &fasta_file_location);
+
 
   void setXmlId(const QString xmlid);
   const QString &getXmlId() const;
 
   private:
-  const QFileInfo _fasta_source;
-  QString _xml_id;
+  QFileInfo m_fastaSource;
+  QString m_xmlId;
 };
 
 Q_DECLARE_METATYPE(FastaFile *)
 Q_DECLARE_METATYPE(FastaFileSp)
-
-#endif // FASTAFILE_H
