@@ -22,8 +22,7 @@
  *implementation
  ******************************************************************************/
 
-#ifndef EDITLABELMETHODS_H
-#define EDITLABELMETHODS_H
+#pragma once
 
 
 #include <QDialog>
@@ -58,4 +57,3 @@ class EditLabelMethods : public QDialog
   QStandardItemModel *_p_label_method_str_li = nullptr;
   LabelingMethodSp _sp_labeling_method;
 };
-#endif // EDITLABELMETHODS_H
