@@ -216,6 +216,8 @@ EditTandemPresetDialog::doSave()
         }
       _p_tandem_preset_file->setDirectory(QDir(_preset_directory));
       _p_tandem_preset_file->setTandemParameters(_tandem_params);
+      QSettings settings;
+      settings.setValue("path/tandemrun_preset_directory", _preset_directory);
       fillPresetComboBox();
       populate();
     }
