@@ -68,6 +68,12 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget *parent)
     {
       ui->spectra_checkbox->setCheckState(Qt::Checked);
     }
+
+  if(settings.value("export_ods/spectra_mobility_informations", "false")
+       .toBool())
+    {
+      ui->spectra_mobility_information_checkbox->setCheckState(Qt::Checked);
+    }
   ui->psm_checkbox->setCheckState(Qt::Unchecked);
   if(settings.value("export_ods/psm", "true").toBool())
     {
@@ -191,6 +197,14 @@ ExportSpreadsheetDialog::doSpectra(bool simple)
   QSettings settings;
   settings.setValue("export_ods/spectra", QString("%1").arg(simple));
 }
+void
+ExportSpreadsheetDialog::doSpectraIonMobilityInformations(bool simple)
+{
+
+  QSettings settings;
+  settings.setValue("export_ods/spectra_mobility_informations",
+                    QString("%1").arg(simple));
+}
 
 void
 ExportSpreadsheetDialog::doPsms(bool simple)
