@@ -114,7 +114,7 @@ MsIdentificationTableModel::getTitle(std::int8_t column)
   switch(column)
     {
       case(std::int8_t)msIdentificationListColumn::align_groups:
-        return "Alignments Groups";
+        return "Alignment groups";
         break;
       case(std::int8_t)msIdentificationListColumn::run_id:
         return "Identification Run ID";
