@@ -34,7 +34,6 @@
 #include <pappsomspp/pappsoexception.h>
 #include "../utils/utils.h"
 #include "output/xpip.h"
-#include "masschroq_run_dialog/masschroqfileparameters.h"
 
 MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
 {
@@ -75,6 +74,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
   // addDockWidget(Qt::RightDockWidgetArea, dock);
 
   qRegisterMetaType<ProjectSp>("ProjectSp");
+  qRegisterMetaType<MasschroqFileParametersSp>("MasschroqFileParametersSp");
   qRegisterMetaType<AutomaticFilterParameters>("AutomaticFilterParameters");
   qRegisterMetaType<GroupingType>("GroupingType");
 
@@ -120,6 +120,12 @@ MainWindow::~MainWindow()
   qDebug();
 }
 
+const ProjectSp &
+MainWindow::getProjectSp() const
+{
+  return _project_sp;
+}
+
 bool
 MainWindow::stopWorkerThread()
 {
@@ -383,7 +389,7 @@ MainWindow::doProjectReady(ProjectSp project_sp)
   if(_project_sp->getAllMsRunAlignmentGroup() == nullptr)
     {
       std::shared_ptr<MsRunAlignmentGroup> all_msrun_group =
-        std::make_shared<MsRunAlignmentGroup>(_project_sp.get(), "all_msrun");
+        std::make_shared<MsRunAlignmentGroup>(_project_sp.get(), "All_samples");
       for(MsRunSp ms_run_sp : _project_sp->getMsRunStore().getMsRunList())
         {
           all_msrun_group->addMsRunToMsRunAlignmentGroupList(ms_run_sp);
@@ -393,7 +399,7 @@ MainWindow::doProjectReady(ProjectSp project_sp)
 
   // Check if the MCQR action can be enabled and add the corresponding actions
   ui->menuAnalyze_one_group->clear();
-  ui->menu_SDS_analysis->clear();
+  ui->menu_XIC_analysis->clear();
   for(MsRunAlignmentGroupSp align_group :
       _project_sp->getMsRunAlignmentGroupList())
     {
@@ -402,7 +408,7 @@ MainWindow::doProjectReady(ProjectSp project_sp)
           ui->menuAnalyze_one_group->addAction(
             align_group->getMsRunAlignmentGroupName());
           bool already_exist = false;
-          for(QAction *action : ui->menu_SDS_analysis->actions())
+          for(QAction *action : ui->menu_XIC_analysis->actions())
             {
               if(action->text() ==
                  QFileInfo(align_group->getMassChroqmlPath()).baseName())
@@ -413,14 +419,20 @@ MainWindow::doProjectReady(ProjectSp project_sp)
           if(!already_exist)
             {
               qDebug() << align_group->getMassChroqmlPath();
-              ui->menu_SDS_analysis->addAction(
+              ui->menu_XIC_analysis->addAction(
                 QFileInfo(align_group->getMassChroqmlPath()).baseName());
             }
         }
     }
-  if(ui->menu_SDS_analysis->actions().size() > 0)
+  if(ui->menu_XIC_analysis->actions().size() > 0)
     {
-      ui->menu_SDS_analysis->setEnabled(true);
+      ui->menu_XIC_analysis->setEnabled(true);
+    }
+  else
+    {
+
+      ui->menu_XIC_analysis->addAction(getProjectSp().get()->getProjectName());
+      ui->menu_XIC_analysis->setEnabled(true);
     }
 
   // Reset masschroq_run_dialog with new project
@@ -614,6 +626,9 @@ MainWindow::doActionSpectralCountingMcq()
 {
   qDebug();
 
+
+  qDebug();
+
   QSettings settings;
   QString default_location = settings.value("path/scmcqfile", "").toString();
 
@@ -633,6 +648,7 @@ MainWindow::doActionSpectralCountingMcq()
   showWaitingMessage(tr("Writing %1 spectral count file for MassChroqR")
                        .arg(QFileInfo(filename).fileName()));
   emit operateWritingMcqrSpectralCountFile(filename, _project_sp);
+
   qDebug();
 }
 
@@ -724,13 +740,11 @@ MainWindow::doActionMassChroQ()
           _p_export_masschroq_dialog = new MassChroqRunDialog(this, mp_worker);
         }
 
-      MasschroqFileParameters params;
-      params.load();
       if(_project_sp.get() != nullptr)
         {
-          _p_export_masschroq_dialog->setMasschroqFileParameters(params);
           _p_export_masschroq_dialog->setProjectSPtr(this->_project_sp);
           _p_export_masschroq_dialog->setAlignmentGroups();
+          _p_export_masschroq_dialog->setMasschroqFileParameters();
         }
       _p_export_masschroq_dialog->show();
       _p_export_masschroq_dialog->raise();
@@ -824,10 +838,13 @@ MainWindow::doAcceptedMassChroqRunDialog()
   try
     {
 
-      MasschroqFileParameters params =
-        _p_export_masschroq_dialog->getMasschroqFileParameters();
-      params.save();
-      qDebug() << params.alignment_groups.size();
+      _p_export_masschroq_dialog->updateMasschroqFileParameters();
+
+      _project_sp.get()->getMasschroqFileParametersSp().get()->save();
+      qDebug() << _project_sp.get()
+                    ->getMasschroqFileParametersSp()
+                    .get()
+                    ->alignment_groups.size();
       QSettings settings;
       QString default_location = settings.value("path/mcqfile", "").toString();
 
@@ -848,7 +865,7 @@ MainWindow::doAcceptedMassChroqRunDialog()
 
       showWaitingMessage(
         tr("Writing %1 MassChroqML file").arg(QFileInfo(filename).fileName()));
-      emit operateWritingMassChroqFile(filename, _project_sp, params);
+      emit operateWritingMassChroqFile(filename, _project_sp);
     }
   catch(pappso::PappsoException &error)
     {
@@ -867,29 +884,61 @@ MainWindow::doAcceptedMcqrParamAllQuantiDialog()
   qDebug() << "begin";
   try
     {
+      QSettings settings;
       McqrExperimentSp mcqr_experiment =
         _project_sp.get()->getMcqrExperimentSp();
-      QSettings settings;
-      QString default_location = settings.value("mcqr/rdata_path").toString();
-      QString rdata_path =
-        QFileDialog::getSaveFileName(this,
-                                     tr("save RData file"),
-                                     tr("%1/%2.RData")
-                                       .arg(default_location)
-                                       .arg(_project_sp->getProjectName()),
-                                     tr("RData files ( *.RData)"));
+      mcqr_experiment.get()->setMcqrExperimentType(
+        McqrExperimentType::spectralCount);
+
+      if(mp_mcqrParamAllQuantiDialog->getMassChroqResultsUsed())
+        { // XIC
+
+          mcqr_experiment.get()->setMcqrExperimentType(McqrExperimentType::xic);
+          if(mp_mcqrParamAllQuantiDialog->getMcqrRunStatus())
+            {
+
+              mcqr_experiment.get()->setMetadataOdsFilePath(
+                mp_mcqrParamAllQuantiDialog->getMetadataOdsFileInfo()
+                  .absoluteFilePath());
+              mcqr_experiment.get()->setMcqrWorkingDirectory(
+                mp_mcqrParamAllQuantiDialog->getMetadataOdsFileInfo()
+                  .absolutePath());
+
+              mp_mcqrRunView = new McqrRunView(this, mcqr_experiment);
+              mp_mcqrRunView->show();
+              mp_mcqrRunView->raise();
+              mp_mcqrRunView->activateWindow();
+              qDebug() << "Run Mcqr!!";
+            }
+        }
+      else
+        { // spectral count
+          QString default_location =
+            settings.value("mcqr/rdata_path").toString();
+          QString rdata_path =
+            QFileDialog::getSaveFileName(this,
+                                         tr("save RData file"),
+                                         tr("%1/%2.RData")
+                                           .arg(default_location)
+                                           .arg(_project_sp->getProjectName()),
+                                         tr("RData files ( *.RData)"));
 
 
-      if(!rdata_path.isEmpty())
-        {
+          if(!rdata_path.isEmpty())
+            {
 
-          mcqr_experiment.get()->setRdataFilePath(
-            QFileInfo(rdata_path).absoluteFilePath());
-          showWaitingMessage(tr("Writing %1 RData file").arg(rdata_path));
-          settings.setValue("mcqr/rdata_path",
-                            mcqr_experiment.get()->getRdataFilePath());
+              mcqr_experiment.get()->setRdataFilePath(
+                QFileInfo(rdata_path).absoluteFilePath());
 
-          emit operateWritingMcqrRData(mcqr_experiment, _project_sp);
+              mcqr_experiment.get()->setMcqrWorkingDirectory(
+                QFileInfo(rdata_path).absolutePath());
+              showWaitingMessage(tr("Writing %1 RData file").arg(rdata_path));
+              settings.setValue("mcqr/rdata_path",
+                                mcqr_experiment.get()->getRdataFilePath());
+
+              emit operateWritingMcqrSpectralCountRdata(mcqr_experiment,
+                                                        _project_sp);
+            }
         }
     }
   catch(pappso::PappsoException &error)
@@ -900,16 +949,14 @@ MainWindow::doAcceptedMcqrParamAllQuantiDialog()
 }
 
 void
-MainWindow::doWritingRdataFileFinished(McqrExperimentSp p_mcqr_experiment)
+MainWindow::doWritingMcqrSpectralCountRdataFinished(
+  McqrExperimentSp p_mcqr_experiment)
 {
   qDebug() << "RData file created";
   hideWaitingMessage();
   if(mp_mcqrParamAllQuantiDialog->getMcqrRunStatus())
     {
-      mp_mcqrRunView =
-        new McqrRunView(this,
-                        p_mcqr_experiment,
-                        mp_mcqrParamAllQuantiDialog->getMassChroqResultsUsed());
+      mp_mcqrRunView = new McqrRunView(this, p_mcqr_experiment);
       mp_mcqrRunView->show();
       mp_mcqrRunView->raise();
       mp_mcqrRunView->activateWindow();
@@ -930,8 +977,8 @@ MainWindow::doWritingMassChroQmlFileFinished(
       showWaitingMessage(tr("Running MassChroQ"));
       emit operateRunningMassChroq(
         _p_export_masschroq_dialog->getMassChroqRunBatchParam());
-      ui->menu_SDS_analysis->addAction(QFileInfo(masschroqml_file).baseName());
-      ui->menu_SDS_analysis->setEnabled(true);
+      ui->menu_XIC_analysis->addAction(QFileInfo(masschroqml_file).baseName());
+      ui->menu_XIC_analysis->setEnabled(true);
       for(MsRunAlignmentGroupSp group : quantified_groups)
         {
           ui->menuAnalyze_one_group->addAction(
