@@ -61,6 +61,10 @@ MassChroqRunDialog::MassChroqRunDialog(MainWindow *parent,
   ui->ht_condor_memory_spin->setValue(
     settings.value("masschroq/condor_request_memory", "5000").toInt());
 
+
+  msp_masschroqFileParametersSp =
+    parent->getProjectSp().get()->getMasschroqFileParametersSp();
+
   setMassChroQRunParamTab();
   mp_poModel = new QStandardItemModel(ui->group_listView);
 
@@ -105,39 +109,69 @@ void
 MassChroqRunDialog::setProjectSPtr(ProjectSp p_project)
 {
   msp_project = p_project;
+  msp_masschroqFileParametersSp =
+    p_project.get()->getMasschroqFileParametersSp();
 }
 
 void
-MassChroqRunDialog::setMasschroqFileParameters(
-  const MasschroqFileParameters &params)
+MassChroqRunDialog::setMasschroqFileParameters()
 {
-  ZivyParams zivy_params;
-  zivy_params.loadSettings();
 
-  ui->zivyParamWidget->setZivyParams(zivy_params);
+  ui->zivyParamWidget->setZivyParams(
+    msp_masschroqFileParametersSp.get()->m_zivyParams);
 
   ui->outputFileFormatComboBox->setCurrentText("ODS");
-  if(params.result_file_format == TableFileFormat::tsv)
+  if(msp_masschroqFileParametersSp.get()->result_file_format ==
+     TableFileFormat::tsv)
     {
       ui->outputFileFormatComboBox->setCurrentText("TSV");
     }
-  setComparFileValue(params.export_compar_file);
+  setComparFileValue(msp_masschroqFileParametersSp.get()->export_compar_file);
 
-  ui->timeCorrectionGroupBox->setChecked(params.write_alignment_times);
-  ui->timeCorrectionDirectoryEdit->setText(params.alignment_times_directory);
+  ui->timeCorrectionGroupBox->setChecked(
+    msp_masschroqFileParametersSp.get()->write_alignment_times);
+  ui->timeCorrectionDirectoryEdit->setText(
+    msp_masschroqFileParametersSp.get()->alignment_times_directory);
 
-  ui->ms2TendencySpinBox->setValue(params.ms2_tendency_half_window);
-  ui->ms2SmoothingSpinBox->setValue(params.ms2_smoothing_half_window);
-  ui->ms1SmoothingSpinBox->setValue(params.ms1_smoothing_half_window);
+  ui->ms2TendencySpinBox->setValue(
+    msp_masschroqFileParametersSp.get()->ms2_tendency_half_window);
+  ui->ms2SmoothingSpinBox->setValue(
+    msp_masschroqFileParametersSp.get()->ms2_smoothing_half_window);
+  ui->ms1SmoothingSpinBox->setValue(
+    msp_masschroqFileParametersSp.get()->ms1_smoothing_half_window);
 
-  ui->xicRangeWidget->setPrecision(params.xic_extraction_range);
+  ui->xicRangeWidget->setPrecision(
+    msp_masschroqFileParametersSp.get()->xic_extraction_range);
 }
 
 
-MasschroqFileParameters
-MassChroqRunDialog::getMasschroqFileParameters() const
+void
+MassChroqRunDialog::updateMasschroqFileParameters() const
 {
-  MasschroqFileParameters params;
+  qDebug();
+  MasschroqFileParameters &params = *(msp_masschroqFileParametersSp.get());
+
+
+  bool has_tims = false;
+  for(auto &msrun :
+      mp_main->getProjectSp().get()->getMsRunStore().getMsRunList())
+    {
+      qDebug();
+      // qDebug() << (int)msrun.get()->getMzFormat();
+      if(msrun.get()->getMzFormat() == pappso::MzFormat::brukerTims)
+        {
+          has_tims = true;
+          break;
+        }
+    }
+  qDebug();
+  if(has_tims)
+    {
+      params.msp_xicFilterSuiteString =
+        std::make_shared<pappso::FilterSuiteString>(
+          "passQuantileBasedRemoveY|0.6");
+    }
+  qDebug();
 
   params.result_file_format = TableFileFormat::ods;
   if(ui->outputFileFormatComboBox->currentText() == "TSV")
@@ -173,9 +207,7 @@ MassChroqRunDialog::getMasschroqFileParameters() const
   params.xic_extraction_method =
     ui->xic_extraction_method_widget->getXicExtractionMethod();
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-           << (int)params.xic_extraction_method;
-  return params;
+  qDebug() << (int)params.xic_extraction_method;
 }
 
 
@@ -347,11 +379,11 @@ MassChroqRunDialog::setAlignmentGroups()
 {
   // Add all msrun stored group (automatic group)
   msp_allMsrunAlignmentGroup = msp_project->getAllMsRunAlignmentGroup();
-  QStandardItem *all_msrun_item =
+  QStandardItem *all_samples_item =
     new QStandardItem(msp_allMsrunAlignmentGroup->getMsRunAlignmentGroupName());
-  all_msrun_item->setCheckable(true);
-  all_msrun_item->setData(Qt::Unchecked, Qt::CheckStateRole);
-  mp_poModel->setItem(0, all_msrun_item);
+  all_samples_item->setCheckable(true);
+  all_samples_item->setData(Qt::Unchecked, Qt::CheckStateRole);
+  mp_poModel->setItem(0, all_samples_item);
 
   // Add classical groups
   msp_alignmentGroups = msp_project->getMsRunAlignmentGroupList();
@@ -381,8 +413,8 @@ MassChroqRunDialog::doShowMsRunsInAlignmentGroup(QModelIndex index)
     {
       msp_selected_group = msp_alignmentGroups.at(index.row() - 1);
     }
-  ui->groupBox_5->setTitle("Ms runs in " +
-                           msp_selected_group->getMsRunAlignmentGroupName());
+  ui->groupBox_5->setTitle("Samples (MS runs) in group \"" +
+                           msp_selected_group->getMsRunAlignmentGroupName() + "\"");
   for(MsRunSp ms_run : msp_selected_group->getMsRunsInAlignmentGroup())
     {
       ui->listWidget->addItem(ms_run->getSampleName());
@@ -502,9 +534,6 @@ MassChroqRunDialog::setMassChroqRunBatchParam(QString masschroqml_file)
   m_masschroqBatchParam.masschroqml_path = masschroqml_file;
   m_masschroqBatchParam.on_disk          = ui->temp_checkbox->isChecked();
   settings.setValue("masschroq/on_disk", ui->temp_checkbox->isChecked());
-  m_masschroqBatchParam.parse_peptide = ui->peptide_checkbox->isChecked();
-  settings.setValue("masschroq/parse_peptide",
-                    ui->peptide_checkbox->isChecked());
 }
 
 void
@@ -526,8 +555,6 @@ MassChroqRunDialog::setMassChroQRunParamTab()
     }
   ui->temp_checkbox->setChecked(
     settings.value("masschroq/on_disk", "false").toBool());
-  ui->peptide_checkbox->setChecked(
-    settings.value("masschroq/parse_peptide", "false").toBool());
 }
 
 void
@@ -546,10 +573,7 @@ MassChroqRunDialog::updateAlignmentGroupsStatus(QString masschroqml_file)
             {
               group = msp_alignmentGroups.at(i - 1);
             }
-          ZivyParams zivy_params;
-          zivy_params.loadSettings();
-          group->savePostMassChroqmlParameters(
-            getMasschroqFileParameters(), zivy_params, masschroqml_file);
+          group->savePostMassChroqmlParameters(masschroqml_file);
           if(getMassChroqRunStatus() == true)
             {
               group->setMassChroQRunStatus(AlignmentGroupStatus::masschroq_run);
