@@ -226,12 +226,11 @@ McqrSdsWidget::analyseQualityData()
         "mcqr_load_data_mode",
         (std::int8_t)getMcqrExperimentSpLoaded().get()->getMcqrLoadDataMode());
       grantlee_context.insert(
-        "rdata_path", getMcqrExperimentSpLoaded().get()->getRdataFilePath());
-      grantlee_context.insert(
-        "rdata_folder",
-        QFileInfo(getMcqrExperimentSpLoaded().get()->getRdataFilePath())
-          .dir()
+        "mcqr_working_directory",
+        QDir(getMcqrExperimentSpLoaded().get()->getMcqrWorkingDirectory())
           .path());
+      grantlee_context.insert(
+        "rdata_path", getMcqrExperimentSpLoaded().get()->getRdataFilePath());
       grantlee_context.insert("specific_peptides",
                               pappso::Utils::booleanToString(
                                 ui->specific_peptide_switch->getSwitchValue()));
@@ -244,8 +243,8 @@ McqrSdsWidget::analyseQualityData()
       grantlee_context.insert("factors_list", factors_list.join("\", \""));
 
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "analyzing_sc", msp_rscriptTemplate->render(&grantlee_context));
     }
 }
 
@@ -292,8 +291,8 @@ McqrSdsWidget::filteringData()
                               ui->fc_cutoff_spinbox->value());
       grantlee_context.insert("factors_list", factors.join("\", \""));
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "filtering_sc", msp_rscriptTemplate->render(&grantlee_context));
     }
 }
 
@@ -349,8 +348,9 @@ McqrSdsWidget::plotProteinHeatmapAbundance()
           grantlee_context.insert("agg_method",
                                   ui->agg_method_combobox->currentText());
 
-          getMcqrRunParentView()->getRProcessRunning()->write(
-            msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+          getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+            "heatmap_abundance",
+            msp_rscriptTemplate->render(&grantlee_context));
         }
       else
         {
@@ -393,8 +393,8 @@ McqrSdsWidget::runProteinClustering()
       grantlee_context.insert("factor_list", factors_list.join("\", \""));
       grantlee_context.insert("nb_cluster", ui->cluster_spin->value());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "protein_clustering", msp_rscriptTemplate->render(&grantlee_context));
     }
 }
 
@@ -435,8 +435,8 @@ McqrSdsWidget::runProteinAnova()
           grantlee_context.insert("interaction", "FALSE");
         }
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "protein_anova", msp_rscriptTemplate->render(&grantlee_context));
     }
 }
 
@@ -486,8 +486,8 @@ McqrSdsWidget::runProteinAbundance()
         }
       grantlee_context.insert("alpha", ui->alpha_spin->value());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "protein_abundance", msp_rscriptTemplate->render(&grantlee_context));
     }
 }
 
@@ -503,8 +503,8 @@ McqrSdsWidget::runProteinFcAbundance()
   grantlee_context.insert("num", ui->numerator_combobox->currentText());
   grantlee_context.insert("denom", ui->denominator_combobox->currentText());
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "protein_fc_abundance", msp_rscriptTemplate->render(&grantlee_context));
 }
 
 void
@@ -526,8 +526,8 @@ McqrSdsWidget::saveFinalRData()
   grantlee_context.insert("mcqr_step", (std::int8_t)m_ongoingMcqrStep);
   grantlee_context.insert("rdata_file", file_name);
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "last", msp_rscriptTemplate->render(&grantlee_context));
 }
 
 void
