@@ -51,6 +51,7 @@ McqrSdsXicWidget::McqrSdsXicWidget(McqrRunView *mcqr_window,
   disableFutureStepsInToolBox();
   addFactorsToListViews();
   initGrantleeEngine();
+  m_mcqrLoadDataMode = p_mcqr_experiment.get()->getMcqrLoadDataMode();
 }
 
 McqrSdsXicWidget::~McqrSdsXicWidget()
@@ -60,16 +61,22 @@ McqrSdsXicWidget::~McqrSdsXicWidget()
 void
 McqrSdsXicWidget::disableFutureStepsInToolBox()
 {
+
+  qDebug();
   int number_of_pages = ui->toolBox->count();
   for(int i = 1; i < number_of_pages; i++)
     {
       ui->toolBox->setItemEnabled(i, false);
     }
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::addFactorsToListViews()
 {
+
+  qDebug();
   int i = 0;
   for(QString factor : getMcqrExperimentSpLoaded().get()->getmetadataColumns())
     {
@@ -97,11 +104,15 @@ McqrSdsXicWidget::addFactorsToListViews()
   ui->factors_list_widget->setVisible(false);
   ui->factors_label_widget->setVisible(false);
   ui->toolBox->adjustSize();
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::changeToolBoxHeight(int tab_selected)
 {
+
+  qDebug();
   ui->toolBox->adjustSize();
   ui->scrollAreaWidgetContents->updateGeometry();
   ui->scrollArea->update();
@@ -180,11 +191,15 @@ McqrSdsXicWidget::changeToolBoxHeight(int tab_selected)
         ui->factors_list_widget->setVisible(false);
         break;
     }
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::initGrantleeEngine()
 {
+
+  qDebug();
   mp_grantleeEngine = new Grantlee::Engine();
   auto loader = QSharedPointer<Grantlee::FileSystemTemplateLoader>::create();
   loader->setTemplateDirs({":/templates/resources/templates/mcqr_scripts"});
@@ -204,17 +219,35 @@ McqrSdsXicWidget::initGrantleeEngine()
               .arg(msp_rscriptTemplate->errorString()));
         }
     }
+  else if(getMcqrExperimentSpLoaded().get()->getMcqrLoadDataMode() ==
+          McqrLoadDataMode::basic)
+    {
+      // if (getMcqrExperimentLoaded()
+      msp_rscriptTemplate =
+        mp_grantleeEngine->loadByName("mcqr_basic_xic_analysis.R");
+      if(!msp_rscriptTemplate->errorString().isEmpty())
+        {
+          throw pappso::PappsoException(
+            QObject::tr(
+              "An error happened during the template file loading :\n%1")
+              .arg(msp_rscriptTemplate->errorString()));
+        }
+    }
   else
     {
       throw pappso::PappsoException(
-        QObject::tr("currently, only fraction experiment can be run inside "
+        QObject::tr("currently, only fraction  experiment can be run inside "
                     "X!TandemPipeline"));
     }
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::changeStepAfterEndTag(QString end_name)
 {
+
+  qDebug();
   if(end_name == "MCQREnd: quality_xic")
     {
       qDebug() << "Configure filtering tab";
@@ -222,7 +255,14 @@ McqrSdsXicWidget::changeStepAfterEndTag(QString end_name)
     }
   else if(end_name == "MCQREnd: filtering_data")
     {
-      configureReconstitutingTab();
+      if(m_mcqrLoadDataMode == McqrLoadDataMode::basic)
+        {
+          configureNormaliseTab();
+        }
+      else
+        {
+          configureReconstitutingTab();
+        }
     }
   else if(end_name == "MCQREnd: reconstiting_fraction")
     {
@@ -278,11 +318,14 @@ McqrSdsXicWidget::changeStepAfterEndTag(QString end_name)
       ui->toolBox->setCurrentIndex(11);
       ui->toolBox->update();
     }
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runQualityCheckingXic()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::quality_xic;
 
   QStringList factors_color;
@@ -295,9 +338,6 @@ McqrSdsXicWidget::runQualityCheckingXic()
         }
     }
 
-  QDir rdata_dir =
-    QFileInfo(getMcqrExperimentSpLoaded().get()->getRdataFilePath()).dir();
-
   MsRunAlignmentGroupSp msrun_alignment_group_sp =
     getMcqrExperimentSpLoaded().get()->getAlignmentGroupLinkedToExperiment();
 
@@ -316,12 +356,12 @@ McqrSdsXicWidget::runQualityCheckingXic()
       Grantlee::Context grantlee_context;
       grantlee_context.insert("mcqr_step", (std::int8_t)m_ongoingMcqrStep);
       grantlee_context.insert(
-        "rdata_folder",
-        QFileInfo(getMcqrExperimentSpLoaded().get()->getRdataFilePath())
-          .dir()
+        "mcqr_working_directory",
+        QDir(getMcqrExperimentSpLoaded().get()->getMcqrWorkingDirectory())
           .path());
       grantlee_context.insert(
-        "rdata_path", getMcqrExperimentSpLoaded().get()->getRdataFilePath());
+        "metadata_ods_path",
+        getMcqrExperimentSpLoaded().get()->getMetadataOdsFilePath());
       grantlee_context.insert("xic_directory", xic_directory_path);
       grantlee_context.insert("rt_interval", ui->rt_interval_spin->value());
       grantlee_context.insert("upper_x_axis", ui->upper_x_axis_spin->value());
@@ -331,14 +371,17 @@ McqrSdsXicWidget::runQualityCheckingXic()
       grantlee_context.insert("sds_page",
                               ui->sds_page_switch->getSwitchValue());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "quality_xic", msp_rscriptTemplate->render(&grantlee_context));
     }
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runFilteringDubiousData()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::filtering_data;
 
   QStringList levels;
@@ -366,13 +409,15 @@ McqrSdsXicWidget::runFilteringDubiousData()
     "fraction_peaks",
     pappso::Utils::booleanToString(ui->peak_fraction_switch->getSwitchValue()));
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "filtering_data", msp_rscriptTemplate->render(&grantlee_context));
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runReconstitutingTracks()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::reconstituting_tracks;
 
   QStringList factors_color;
@@ -422,14 +467,19 @@ McqrSdsXicWidget::runReconstitutingTracks()
       grantlee_context.insert("track_level",
                               ui->track_ref_combobox->currentText());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "reconstituting_tracks",
+        msp_rscriptTemplate->render(&grantlee_context));
     }
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runNormaliseIntensities()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::normalise;
 
   QStringList factors_color;
@@ -479,14 +529,16 @@ McqrSdsXicWidget::runNormaliseIntensities()
       grantlee_context.insert("norm_method",
                               ui->norm_method_combo->currentText());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "normalise", msp_rscriptTemplate->render(&grantlee_context));
     }
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runFilteringSharedPeptides()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::filtering_shared;
 
   QStringList factors_list;
@@ -518,14 +570,17 @@ McqrSdsXicWidget::runFilteringSharedPeptides()
       grantlee_context.insert("corr_cutoff", ui->corr_cutoff_spin->value());
       grantlee_context.insert("n_prot_corr", ui->nb_prot_corr_spin->value());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "filtering_shared", msp_rscriptTemplate->render(&grantlee_context));
     }
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runFilteringUncorrelatedPeptides()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::filtering_uncorrelated;
 
   QStringList factors_list;
@@ -554,14 +609,18 @@ McqrSdsXicWidget::runFilteringUncorrelatedPeptides()
       grantlee_context.insert("corr_cutoff", ui->corr_cutoff_spin->value());
       grantlee_context.insert("nb_pep", ui->nb_peptides_cutoff_spin->value());
 
-      getMcqrRunParentView()->getRProcessRunning()->write(
-        msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+
+      getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+        "filtering_uncorrelated",
+        msp_rscriptTemplate->render(&grantlee_context));
     }
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runImputingPeptidesProteins()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::imputing;
 
   QStringList factors_list;
@@ -583,13 +642,16 @@ McqrSdsXicWidget::runImputingPeptidesProteins()
   grantlee_context.insert("abundance_method",
                           ui->abundance_method_combo->currentText());
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "imputing", msp_rscriptTemplate->render(&grantlee_context));
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runHeatMapProteinAbundance()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::heatmap;
 
   QStringList factors_list;
@@ -618,13 +680,15 @@ McqrSdsXicWidget::runHeatMapProteinAbundance()
   grantlee_context.insert("distance_fun", ui->distfun_combobox->currentText());
   grantlee_context.insert("agg_method", ui->agg_method_combobox->currentText());
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "heatmap", msp_rscriptTemplate->render(&grantlee_context));
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runProteinClustering()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::protein_clustering;
 
   QStringList factors_list;
@@ -644,13 +708,16 @@ McqrSdsXicWidget::runProteinClustering()
                           transformQStringListInRListFormat(factors_list));
   grantlee_context.insert("nb_cluster", ui->cluster_spin->value());
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "protein_clustering", msp_rscriptTemplate->render(&grantlee_context));
+
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runProteinAnova()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::anova;
 
   QStringList factors_list;
@@ -673,13 +740,15 @@ McqrSdsXicWidget::runProteinAnova()
                           pappso::Utils::booleanToString(
                             ui->interaction_anova_switch->getSwitchValue()));
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "anova", msp_rscriptTemplate->render(&grantlee_context));
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runProteinAbundance()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::protein_abundance;
 
   QStringList factors_list;
@@ -711,13 +780,16 @@ McqrSdsXicWidget::runProteinAbundance()
     pappso::Utils::booleanToString(ui->padjust_switch->getSwitchValue()));
   grantlee_context.insert("alpha", ui->alpha_spin->value());
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "protein_abundance", msp_rscriptTemplate->render(&grantlee_context));
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::runProteinFcAbundance()
 {
+  qDebug();
   m_ongoingMcqrStep = SdsXicAnalysisStep::protein_fc_abundance;
 
   Grantlee::Context grantlee_context;
@@ -727,13 +799,15 @@ McqrSdsXicWidget::runProteinFcAbundance()
   grantlee_context.insert("num", ui->numerator_combobox->currentText());
   grantlee_context.insert("denom", ui->denominator_combobox->currentText());
 
-  getMcqrRunParentView()->getRProcessRunning()->write(
-    msp_rscriptTemplate->render(&grantlee_context).toUtf8());
+  getMcqrRunParentView()->getRProcessRunning()->executeMcqrStep(
+    "protein_fc_abundance", msp_rscriptTemplate->render(&grantlee_context));
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::configureFilteringTab()
 {
+  qDebug();
   mp_factorLevelsToRemove = new QStandardItemModel(ui->levels_remove_view);
   // Configure combobox to store the list of factors
   for(QString factor : getMcqrExperimentSpLoaded().get()->getmetadataColumns())
@@ -753,11 +827,13 @@ McqrSdsXicWidget::configureFilteringTab()
   ui->toolBox->setItemEnabled(1, true);
   ui->toolBox->setCurrentIndex(1);
   ui->toolBox->update();
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::configureReconstitutingTab()
 {
+  qDebug();
   QStringList levels;
   for(McqrMetadata *metadata :
       getMcqrExperimentSpLoaded().get()->getmetadataInfoVector())
@@ -773,18 +849,27 @@ McqrSdsXicWidget::configureReconstitutingTab()
   ui->toolBox->setItemEnabled(2, true);
   ui->toolBox->setCurrentIndex(2);
   ui->toolBox->update();
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::configureNormaliseTab()
 {
+  qDebug();
   QStringList levels;
   for(McqrMetadata *metadata :
       getMcqrExperimentSpLoaded().get()->getmetadataInfoVector())
     {
-      if(!levels.contains(metadata->m_otherData["track"].toString()))
+      if(m_mcqrLoadDataMode == McqrLoadDataMode::basic)
         {
-          levels << metadata->m_otherData["track"].toString();
+          levels << metadata->m_msrunId;
+        }
+      else
+        {
+          if(!levels.contains(metadata->m_otherData["track"].toString()))
+            {
+              levels << metadata->m_otherData["track"].toString();
+            }
         }
     }
   ui->norm_ref_track_combo->addItems(levels);
@@ -792,15 +877,18 @@ McqrSdsXicWidget::configureNormaliseTab()
   ui->toolBox->setItemEnabled(3, true);
   ui->toolBox->setCurrentIndex(3);
   ui->toolBox->update();
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::configureFcFactorList()
 {
+  qDebug();
   for(QString factor : getMcqrExperimentSpLoaded().get()->getmetadataColumns())
     {
       ui->factor_combobox->addItem(factor);
     }
+  qDebug();
 }
 
 void
@@ -842,11 +930,13 @@ McqrSdsXicWidget::updateLevelToRemoveList(QString factor)
       i++;
     }
   //     ui->levels_remove_view->setModel(mp_factorLevelsToRemove);
+  qDebug();
 }
 
 void
 McqrSdsXicWidget::updateNumeratorAndDenominatorComboboxFc(QString factor)
 {
+  qDebug();
   ui->numerator_combobox->clear();
   ui->denominator_combobox->clear();
   QStringList factors_list;
@@ -863,4 +953,5 @@ McqrSdsXicWidget::updateNumeratorAndDenominatorComboboxFc(QString factor)
       ui->denominator_combobox->addItem(factor_value);
       ui->numerator_combobox->addItem(factor_value);
     }
+  qDebug();
 }
