@@ -204,15 +204,15 @@ PeptideWindow::setIon(pappso::PeakIonIsotopeMatchCstSPtr ion)
     }
   else
     {
-      QString plusstr = "+";
-      plusstr         = plusstr.repeated(ion->getCharge());
+      // String plusstr = "+";
+      // plusstr         = plusstr.repeated(ion->getCharge());
       _ion_label->setText(
-        QString("%1%2%3 (+%4) - th. isotope ratio %5%")
-          .arg(ion->getPeptideFragmentIonSp().get()->getPeptideIonName())
-          .arg(ion->getPeptideFragmentIonSp().get()->size())
-          .arg(plusstr)
+        QString("%1 (+%2) - %3 - th. isotope ratio %4%")
+          .arg(ion->getPeptideFragmentIonSp().get()->getCompletePeptideIonName(
+            ion->getCharge()))
           .arg(
             ion->getPeptideNaturalIsotopeAverageSp().get()->getIsotopeNumber())
+          .arg(ion->getPeptideFragmentIonSp().get()->getSequence())
           .arg((int)(ion->getPeptideNaturalIsotopeAverageSp()
                        .get()
                        ->getIntensityRatio() *
@@ -424,8 +424,7 @@ PeptideWindow::openInPeptideViewer()
             << _p_peptide_evidence->getMsRunP()->getFileName()
             << QString("%1").arg(_p_peptide_evidence->getScanNumber());
 
-  qDebug()  << program << " "
-           << arguments.join(" ");
+  qDebug() << program << " " << arguments.join(" ");
   QProcess *myProcess = new QProcess(this);
   myProcess->start(program, arguments);
 }
