@@ -1229,8 +1229,7 @@ ProjectWindow::doExportXicAreaToCsv(QString filename,
 {
   qDebug() << "Export Xic to csv";
   showWaitingMessage("Export All XIC area to CSV");
-  QString project_name = getProjectSP()->getProjectName();
-  emit operateWriteXicAreaInCsv(filename, project_name, xic_boxs);
+  emit operateWriteXicAreaInCsv(filename, getProjectSP(), xic_boxs);
 }
 void
 ProjectWindow::doExportXicAreaToCsvFinished()
