@@ -150,7 +150,7 @@ class ProjectWindow : public QMainWindow
   void bestMsRunFound(MsRunSp msrun_sp);
   void operateMassChroqExportDialog();
   void operateWriteXicAreaInCsv(QString filename,
-                                QString project_name,
+                                ProjectSp project_sp,
                                 std::vector<XicBox *> xic_boxs);
 
   // @brief emit this when peptide/protein filters are done (finished)
