@@ -128,8 +128,7 @@ TandemRunDialog::setPresetName(QString preset_name)
                 {
 
                   QMessageBox::warning(
-                    this,
-                    tr("Error reading X!Tandem parameter file"),
+                    this, tr("Error reading X!Tandem parameter file"),
                     tr("Error reading parameter file \"%1\":\n%2")
                       .arg(param_file.getAbsoluteFilePath())
                       .arg(error.qwhat()));
@@ -242,13 +241,9 @@ TandemRunDialog::editPresets()
 
 #if QT_VERSION >= 0x050000
   // Qt5 code
-  connect(_p_preset_dialog,
-          &EditTandemPresetDialog::accepted,
-          this,
+  connect(_p_preset_dialog, &EditTandemPresetDialog::accepted, this,
           &TandemRunDialog::acceptPresetEdit);
-  connect(_p_preset_dialog,
-          &EditTandemPresetDialog::rejected,
-          this,
+  connect(_p_preset_dialog, &EditTandemPresetDialog::rejected, this,
           &TandemRunDialog::rejectPresetEdit);
 #else
   // Qt4 code
@@ -315,9 +310,7 @@ TandemRunDialog::selectFastaFiles()
         settings.value("path/tandemrun_fastafiles_directory", "").toString();
 
       QStringList filenames = QFileDialog::getOpenFileNames(
-        this,
-        tr("FASTA files"),
-        default_fasta_location,
+        this, tr("FASTA files"), default_fasta_location,
         tr("FASTA files (*.fasta);;all files (*)"));
 
       if(filenames.size() > 0)
@@ -348,8 +341,7 @@ TandemRunDialog::selectXtandemExe()
 
 
       QString filename =
-        QFileDialog::getOpenFileName(this,
-                                     tr("select X!Tandem executable"),
+        QFileDialog::getOpenFileName(this, tr("select X!Tandem executable"),
                                      QDir(tandem_bin_path).absolutePath(),
                                      tr("all files (*);;exe files (*.exe)"));
       fillTandemBinPath(filename, true);
@@ -372,9 +364,7 @@ TandemRunDialog::selectMzFiles()
         settings.value("path/tandemrun_mzfiles_directory", "").toString();
 
       QStringList filenames = QFileDialog::getOpenFileNames(
-        this,
-        tr("select peak list files"),
-        default_mz_location,
+        this, tr("select peak list files"), default_mz_location,
         tr("any mz files (*.mzXML *.mzxml *.mzML *.mzml *.mgf *.tdf);;mzXML "
            "(*.mzXML "
            "*.mzxml);;mzML (*.mzML *.mzml);;MGF (*.mgf);; tdf (*.tdf);;all "
@@ -656,8 +646,7 @@ TandemRunDialog::fillTandemBinPath(const QString &tandem_bin_path_in,
               QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
             }
           QMessageBox::warning(
-            this,
-            tr("Wrong tandem.exe file"),
+            this, tr("Wrong tandem.exe file"),
             tr("%1 is not executable.").arg(tandem_bin_path));
         }
     }
@@ -679,8 +668,7 @@ TandemRunDialog::checkXtandemBin()
   if((tandem_bin_path.isEmpty()) || (tandem_bin.baseName() == "xtpcpp"))
     {
       QMessageBox::warning(
-        this,
-        tr("Wrong X!Tandem configuration"),
+        this, tr("Wrong X!Tandem configuration"),
         tr("X!Tandem .exe file is not set.\n%1").arg(tandem_install_text));
 
       QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
@@ -700,8 +688,7 @@ TandemRunDialog::checkXtandemBin()
           catch(pappso::PappsoException &error)
             {
               QMessageBox::warning(
-                this,
-                tr("Wrong X!Tandem exe file"),
+                this, tr("Wrong X!Tandem exe file"),
                 tr("%1 does not seem to be a valid X!Tandem version.\n%2")
                   .arg(tandem_bin.absoluteFilePath())
                   .arg(tandem_install_text));
@@ -711,8 +698,7 @@ TandemRunDialog::checkXtandemBin()
         }
       else
         {
-          QMessageBox::warning(this,
-                               tr("Wrong X!Tandem exe file"),
+          QMessageBox::warning(this, tr("Wrong X!Tandem exe file"),
                                tr("%1 is not executable.\n%2")
                                  .arg(tandem_bin_path)
                                  .arg(tandem_install_text));
