@@ -17,9 +17,6 @@
  *     You should have received a copy of the GNU General Public License
  *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contributors:
- *     Olivier Langella <olivier.langella@u-psud.fr> - initial API and
- *implementation
  ******************************************************************************/
 
 #include "ui_waiting_message_dialog.h"
@@ -31,7 +28,7 @@
 WaitingMessageDialog::WaitingMessageDialog(QWidget *parent)
   : QDialog(parent), ui(new Ui::WaitingMessageDialog)
 {
-  qDebug() << "WaitingMessageDialog::WaitingMessageDialog begin";
+  qDebug() << "begin";
   ui->setupUi(this);
   this->setModal(true);
   this->setWindowFlags(Qt::Window | Qt::WindowTitleHint |
@@ -43,8 +40,7 @@ WaitingMessageDialog::WaitingMessageDialog(QWidget *parent)
     new QMovie(":/xtpcpp_icon/resources/xtandempipeline_animated_gif.gif");
   if(!_p_movie->isValid())
     {
-      qDebug()
-        << "WaitingMessageDialog::WaitingMessageDialog animation not found";
+      qDebug() << " animation not found";
     }
   ui->movie_label->setMovie(_p_movie);
   ui->progress_bar->setVisible(false);
@@ -52,53 +48,57 @@ WaitingMessageDialog::WaitingMessageDialog(QWidget *parent)
   ui->progress_bar->setMaximum(100);
   ui->progress_bar->setMinimum(0);
   ui->console_plaintextedit->setHidden(true);
-  ui->stop_push_button->setVisible(false);
-  _asked_to_stop = false;
+  ui->stop_push_button->setHidden(true);
+  ui->stop_push_button->setChecked(false);
   // movie->start();
-  qDebug() << "WaitingMessageDialog::WaitingMessageDialog end";
+  qDebug() << " end";
 }
 
 WaitingMessageDialog::~WaitingMessageDialog()
 {
-  qDebug() << "WaitingMessageDialog::~WaitingMessageDialog";
+  qDebug();
   delete ui;
-  qDebug() << "WaitingMessageDialog::~WaitingMessageDialog end";
-}
-
-void
-WaitingMessageDialog::toggledStopButton(bool pushed [[maybe_unused]])
-{
-  QMutexLocker mutex_locker(&_mutex);
-  _asked_to_stop = true;
+  qDebug();
 }
 
 bool
 WaitingMessageDialog::stopWorkerThread()
 {
-  QMutexLocker mutex_locker(&_mutex);
-  if(!ui->stop_push_button->isVisible())
+  QMutexLocker mutex_locker(&m_mutex);
+  qDebug();
+  if(ui->stop_push_button->isHidden())
     {
-      ui->stop_push_button->setChecked(false);
-      ui->stop_push_button->setVisible(true);
-      _asked_to_stop = false;
-      return false;
+      qDebug();
+      // DO NOT TOUCH directly to the UI in an other thread :not safe
+      // ui->stop_push_button->setChecked(false);
+      // ui->stop_push_button->setHidden(false);
     }
-  return _asked_to_stop;
+  else
+    {
+      qDebug();
+      if(ui->stop_push_button->isChecked())
+        {
+          qDebug();
+          return true;
+        }
+    }
+  qDebug();
+  return false;
 }
 
 void
 WaitingMessageDialog::message(const QString &message)
 {
-  QMutexLocker mutex_locker(&_mutex);
-  ui->progress_bar->setVisible(false);
+  QMutexLocker mutex_locker(&m_mutex);
+  //ui->progress_bar->setVisible(false);
   ui->message_label->setText(message);
 }
 
 void
 WaitingMessageDialog::message(const QString &message, int progress_value)
 {
-  QMutexLocker mutex_locker(&_mutex);
-  qDebug() << "WaitingMessageDialog::message " << progress_value;
+  QMutexLocker mutex_locker(&m_mutex);
+  qDebug() << progress_value;
   ui->progress_bar->setVisible(true);
   ui->progress_bar->setValue(progress_value);
   ui->message_label->setText(message);
@@ -107,7 +107,7 @@ WaitingMessageDialog::message(const QString &message, int progress_value)
 void
 WaitingMessageDialog::appendText(const char *text)
 {
-  QMutexLocker mutex_locker(&_mutex);
+  QMutexLocker mutex_locker(&m_mutex);
   ui->console_plaintextedit->setHidden(false);
   // ui->console_plaintextedit->appendText(text);
 
@@ -115,10 +115,23 @@ WaitingMessageDialog::appendText(const char *text)
   ui->console_plaintextedit->insertPlainText(text);
 }
 
+void
+WaitingMessageDialog::appendText(const QString &message)
+{
+
+  QMutexLocker mutex_locker(&m_mutex);
+  ui->console_plaintextedit->setHidden(false);
+  // ui->console_plaintextedit->appendText(text);
+
+  ui->console_plaintextedit->moveCursor(QTextCursor::End);
+  ui->console_plaintextedit->insertPlainText(message);
+}
+
+
 void
 WaitingMessageDialog::setText(const QString text)
 {
-  QMutexLocker mutex_locker(&_mutex);
+  QMutexLocker mutex_locker(&m_mutex);
   ui->console_plaintextedit->setHidden(false);
   // ui->console_plaintextedit->appendText(text);
   ui->console_plaintextedit->setPlainText(text);
@@ -127,19 +140,45 @@ WaitingMessageDialog::setText(const QString text)
 void
 WaitingMessageDialog::hideEvent(QHideEvent *event)
 {
-  QMutexLocker mutex_locker(&_mutex);
+  QMutexLocker mutex_locker(&m_mutex);
   QWidget::hideEvent(event);
-  qDebug() << "WaitingMessageDialog::hideEvent";
+  qDebug();
   _p_movie->stop();
   ui->console_plaintextedit->setHidden(true);
+  qDebug();
 }
 void
 WaitingMessageDialog::showEvent(QShowEvent *event)
 {
-  QMutexLocker mutex_locker(&_mutex);
+  qDebug();
+  QMutexLocker mutex_locker(&m_mutex);
+  qDebug();
   QWidget::showEvent(event);
+  qDebug();
   _p_movie->start();
+  qDebug();
   ui->stop_push_button->setChecked(false);
-  ui->stop_push_button->setVisible(false);
-  _asked_to_stop = false;
+  qDebug();
+  ui->stop_push_button->setHidden(true);
+  qDebug();
+  ui->console_plaintextedit->clear();
+  qDebug();
+}
+
+
+void
+WaitingMessageDialog::showStopButton()
+{
+  ui->stop_push_button->setChecked(false);
+  ui->stop_push_button->setHidden(false);
+}
+
+void
+WaitingMessageDialog::percent(int progress_value)
+{
+
+  QMutexLocker mutex_locker(&m_mutex);
+  qDebug() << progress_value;
+  ui->progress_bar->setVisible(true);
+  ui->progress_bar->setValue(progress_value);
 }
