@@ -157,13 +157,13 @@ WorkerThread::WorkerThread(MainWindow *p_main_window)
           &WorkerThread::doRunningMassChroQ);
   // Mcqr write
   connect(p_main_window,
-          &MainWindow::operateWritingMcqrRData,
+          &MainWindow::operateWritingMcqrSpectralCountRdata,
           this,
-          &WorkerThread::doWritingMcqrRDataFile);
+          &WorkerThread::doWritingMcqrSpectralCountRdata);
   connect(this,
-          &WorkerThread::operateWritingRDataFileFinished,
+          &WorkerThread::operateWritingMcqrSpectralCountRdataFinished,
           p_main_window,
-          &MainWindow::doWritingRdataFileFinished);
+          &MainWindow::doWritingMcqrSpectralCountRdataFinished);
 
   // protic write
   connect(p_main_window,
@@ -475,9 +475,7 @@ WorkerThread::doWritingOdsFile(QString filename,
 
 
 void
-WorkerThread::doWritingMassChroqFile(QString filename,
-                                     ProjectSp project_sp,
-                                     MasschroqFileParameters params)
+WorkerThread::doWritingMassChroqFile(QString filename, ProjectSp project_sp)
 {
 
   try
@@ -485,12 +483,17 @@ WorkerThread::doWritingMassChroqFile(QString filename,
       emit loadingMessage(tr("writing MassChroqML file, please wait"));
 
       project_sp.get()->checkPsimodCompliance();
-      MassChroQml output(filename, params);
+      MassChroQml output(
+        filename, *(project_sp.get()->getMasschroqFileParametersSp().get()));
       output.write(project_sp);
       output.close();
       emit operationFinished();
-      emit operateWritingMassChroqFileFinished(filename,
-                                               params.alignment_groups);
+      emit operateWritingMassChroqFileFinished(
+        filename,
+        project_sp.get()
+          ->getMasschroqFileParametersSp()
+          .get()
+          ->alignment_groups);
     }
   catch(pappso::PappsoException &error)
     {
@@ -500,57 +503,14 @@ WorkerThread::doWritingMassChroqFile(QString filename,
 }
 
 void
-WorkerThread::doWritingMcqrRDataFile(McqrExperimentSp mcqr_experiment_sp,
-                                     ProjectSp project_sp)
+WorkerThread::doWritingMcqrSpectralCountRdata(
+  McqrExperimentSp mcqr_experiment_sp, ProjectSp project_sp)
 {
-  // mcqr_experiment_sp.get()->getRdataFilePath();
-  QString rdata_dir =
-    QFileInfo(mcqr_experiment_sp.get()->getRdataFilePath()).absolutePath();
-  qDebug() << " rdata_path=" << mcqr_experiment_sp.get()->getRdataFilePath();
-  QTemporaryDir *tmp_rdata_dir_p = new QTemporaryDir(rdata_dir + "/output");
-  tmp_rdata_dir_p->setAutoRemove(true);
-
-  if(!tmp_rdata_dir_p->isValid())
-    {
-      throw pappso::PappsoException(
-        QObject::tr(
-          "problem creating Rdata writing temporary directory in %1\n")
-          .arg(rdata_dir));
-    }
-
-  emit loadingMessage(tr("writing MCQR metadata file, please wait"));
-  QString meta_rdata_path    = tmp_rdata_dir_p->path() + "/meta.RData";
-  McqrRdata *mcqr_rdata_meta = new McqrRdata(meta_rdata_path, project_sp);
-  mcqr_rdata_meta->writeMetaDataTable();
-  mcqr_rdata_meta->closeMCQRDataFile();
-
-  emit loadingMessage(tr("writing MCQR summary file, please wait"));
-  QString summary_rdata_path = tmp_rdata_dir_p->path() + "/summary.RData";
-  McqrRdata *summ_mcqr_rdata = new McqrRdata(summary_rdata_path, project_sp);
-  summ_mcqr_rdata->writeExperimentalSummaryTable();
-  summ_mcqr_rdata->closeMCQRDataFile();
-
-  emit loadingMessage(tr("writing MCQR spectral count file, please wait"));
-  QString sc_rdata_path    = tmp_rdata_dir_p->path() + "/sc.RData";
-  McqrRdata *mcqr_rdata_sc = new McqrRdata(sc_rdata_path, project_sp);
-  mcqr_rdata_sc->writeSpectraCountTable();
-  mcqr_rdata_sc->closeMCQRDataFile();
-
-  emit loadingMessage(tr("writing MCQR quantification info file, please wait"));
-  QString quanti_rdata_path    = tmp_rdata_dir_p->path() + "/quanti.RData";
-  McqrRdata *mcqr_rdata_quanti = new McqrRdata(quanti_rdata_path, project_sp);
-  mcqr_rdata_quanti->writeQuantiInfoTable();
-  mcqr_rdata_quanti->closeMCQRDataFile();
-
-  emit loadingMessage(tr("Merging MCQR rdata files, please wait"));
-  QString rscript_path = McqrRdata::createTheMergeRScript(
-    tmp_rdata_dir_p->path(),
-    mcqr_experiment_sp.get()->getRdataFilePath(),
-    mcqr_experiment_sp.get()->getMassChroqMlFilePath());
-  McqrRdata::mergeTheRDataFiles(rscript_path);
-  tmp_rdata_dir_p->remove();
   // emit operationFinished();
-  emit operateWritingRDataFileFinished(project_sp->getMcqrExperimentSp());
+  McqrRdata sc_rdata_writer(mcqr_experiment_sp, project_sp);
+  sc_rdata_writer.writeSpectralCountData(*_p_work_monitor);
+  emit operateWritingMcqrSpectralCountRdataFinished(
+    project_sp->getMcqrExperimentSp());
 }
 
 void
@@ -1013,7 +973,7 @@ WorkerThread::doCheckMsrunFilePath(ProjectSp msp_project)
 
 void
 WorkerThread::doWriteXicAreaInCsv(QString filename,
-                                  QString project_name,
+                                  ProjectSp project_sp,
                                   std::vector<XicBox *> xic_boxs)
 {
   CalcWriterInterface *p_writer = nullptr;
@@ -1025,20 +985,22 @@ WorkerThread::doWriteXicAreaInCsv(QString filename,
   p_writer = new TsvDirectoryWriter(filename);
   if(xic_export_file == "both")
     {
-      XicAreaSheet(p_writer, project_name, xic_boxs);
+      XicAreaSheet(p_writer, project_sp.get()->getProjectName(), xic_boxs);
       bool all_data = true;
-      XicAreaSheet(p_writer, project_name, xic_boxs, all_data);
+      XicAreaSheet(
+        p_writer, project_sp.get()->getProjectName(), xic_boxs, all_data);
     }
   else if(xic_export_file == "all")
     {
       bool all_data = true;
-      XicAreaSheet(p_writer, project_name, xic_boxs, all_data);
+      XicAreaSheet(
+        p_writer, project_sp.get()->getProjectName(), xic_boxs, all_data);
     }
   else // xic_export_file == "area"
     {
-      XicAreaSheet(p_writer, project_name, xic_boxs);
+      XicAreaSheet(p_writer, project_sp.get()->getProjectName(), xic_boxs);
     }
-  XicInfoSheet(p_writer, project_name, xic_boxs);
+  XicInfoSheet(p_writer, project_sp, xic_boxs);
   p_writer->close();
   emit exportXicToCsvFinished();
 }
