@@ -164,17 +164,13 @@ XicBox::XicBox(XicWindow *parent) : QWidget(parent), ui(new Ui::XicBox)
   connect(p_worker, &XicWorkerThread::operationFailed, this, &XicBox::error);
 
 
-  connect(this,
-          &XicBox::computeIsotopeMassList,
-          p_worker,
+  connect(this, &XicBox::computeIsotopeMassList, p_worker,
           &XicWorkerThread::doComputeIsotopeMassList);
-  connect(p_worker,
-          &XicWorkerThread::isotopeMassListComputed,
-          this,
+  connect(p_worker, &XicWorkerThread::isotopeMassListComputed, this,
           &XicBox::setIsotopeMassList);
 
-  connect(
-    _p_xic_window, &XicWindow::reExtractXicNeeded, this, &XicBox::reExtractXic);
+  connect(_p_xic_window, &XicWindow::reExtractXicNeeded, this,
+          &XicBox::reExtractXic);
   /*  connect(ui->xic_widget,
           qOverload<std::vector<std::pair<pappso::XicCstSPtr,
   pappso::XicPeakSp>>>( &pappso::XicWidget::xicPeakListChanged), this,
@@ -185,23 +181,19 @@ XicBox::XicBox(XicWindow *parent) : QWidget(parent), ui(new Ui::XicBox)
           this,
           &XicBox::onXicWidgetClick);
 */
-  connect(_p_xic_window,
-          &XicWindow::rtUnitChangeNeeded,
-          this,
+  connect(_p_xic_window, &XicWindow::rtUnitChangeNeeded, this,
           &XicBox::onRtUnitChanged);
 
   /** @brief Handle axis size to move simultaneously in boxs
    */
   connect(ui->xic_widget->getRtAxisP(),
-          qOverload<const QCPRange &>(&QCPAxis::rangeChanged),
-          this,
+          qOverload<const QCPRange &>(&QCPAxis::rangeChanged), this,
           &XicBox::doGetNewRtRange);
   connect(ui->xic_widget->getIntensityAxisP(),
-          qOverload<const QCPRange &>(&QCPAxis::rangeChanged),
-          this,
+          qOverload<const QCPRange &>(&QCPAxis::rangeChanged), this,
           &XicBox::doGetNewIntensityRange);
-  connect(
-    this, &XicBox::fitAxisRangeInXics, _p_xic_window, &XicWindow::doFitAllAxis);
+  connect(this, &XicBox::fitAxisRangeInXics, _p_xic_window,
+          &XicWindow::doFitAllAxis);
 
 #else
 // Qt4 code
@@ -251,11 +243,6 @@ XicBox::getRtRange()
   return ui->xic_widget->getRtAxisP()->range();
 }
 
-ZivyParams
-XicBox::getZivyParamsUsed()
-{
-  return _p_xic_window->getZivyParams();
-}
 
 void
 XicBox::onXicWidgetClick(double rt [[maybe_unused]],
@@ -343,8 +330,7 @@ XicBox::setPeptideEvidence(const PeptideEvidence *p_peptide_evidence)
   _p_xic_window->getProjectWindow()
     ->getProjectP()
     ->getSameXicPeptideEvidenceList(
-      _peptide_evidence_list,
-      _msrun_sp.get(),
+      _peptide_evidence_list, _msrun_sp.get(),
       _p_peptide_evidence->getPeptideXtpSp().get(),
       _p_peptide_evidence->getCharge());
 
@@ -377,8 +363,7 @@ XicBox::setPeptideEvidenceInMsRun(const PeptideEvidence *p_peptide_evidence,
   _p_xic_window->getProjectWindow()
     ->getProjectP()
     ->getSameXicPeptideEvidenceList(
-      _peptide_evidence_list,
-      _msrun_sp.get(),
+      _peptide_evidence_list, _msrun_sp.get(),
       _p_peptide_evidence->getPeptideXtpSp().get(),
       _p_peptide_evidence->getCharge());
   //_p_xic_window->getProjectWindow()->getProjectP()->getSameXicPeptideEvidenceList(p_peptide_evidence,
@@ -589,8 +574,7 @@ XicBox::drawObservedAreaBars(
         }
       else
         {
-          addCommonRt(common_peak_rt_measure_list,
-                      peak_to_draw.get(),
+          addCommonRt(common_peak_rt_measure_list, peak_to_draw.get(),
                       xic_isotope.xic_sp.get());
 
 
@@ -675,13 +659,17 @@ XicBox::setIsotopeMassList(
 {
   _natural_isotope_list.clear();
 
+  MasschroqFileParametersSp params = _p_xic_window->getProjectWindow()
+                                       ->getProjectSP()
+                                       .get()
+                                       ->getMasschroqFileParametersSp();
   pappso::XicCoordSPtr xic_coord_ref =
     _msrun_sp.get()
       ->getMsRunReaderSPtr()
       .get()
       ->newXicCoordSPtrFromSpectrumIndex(
         _p_peptide_evidence->getSpectrumIndexByScanNumber(),
-        _p_xic_window->getXicExtractPrecision());
+        params.get()->xic_extraction_range);
 
   std::vector<pappso::XicCoordSPtr> mass_list;
   for(pappso::PeptideNaturalIsotopeAverageSp &natural_isotope_average :
@@ -692,7 +680,7 @@ XicBox::setIsotopeMassList(
         xic_coord_ref.get()->initializeAndClone();
       xic_coord.get()->mzRange =
         pappso::MzRange(natural_isotope_average.get()->getMz(),
-                        _p_xic_window->getXicExtractPrecision());
+                        params.get()->xic_extraction_range);
       mass_list.push_back(xic_coord);
 
       _natural_isotope_list.push_back({xic_coord.get()->xicSptr,
@@ -702,7 +690,11 @@ XicBox::setIsotopeMassList(
                                        {}});
     }
 
-  emit loadXic(_msrun_sp, mass_list, pappso::XicExtractMethod::max);
+  emit loadXic(_msrun_sp, mass_list,
+               _p_xic_window->getProjectWindow()
+                 ->getProjectSP()
+                 .get()
+                 ->getMasschroqFileParametersSp());
 
   // histogram
   if(m_theoreticalRatioBars == nullptr)
@@ -785,13 +777,19 @@ XicBox::reExtractXic()
   qDebug();
   ui->xic_widget->clear();
 
+  MasschroqFileParametersSp params = _p_xic_window->getProjectWindow()
+                                       ->getProjectSP()
+                                       .get()
+                                       ->getMasschroqFileParametersSp();
+
+
   pappso::XicCoordSPtr xic_coord_ref =
     _msrun_sp.get()
       ->getMsRunReaderSPtr()
       .get()
       ->newXicCoordSPtrFromSpectrumIndex(
-        _p_peptide_evidence->getSpectrumIndex(),
-        _p_xic_window->getXicExtractPrecision());
+        _p_peptide_evidence->getSpectrumIndexByScanNumber(),
+        params.get()->xic_extraction_range);
 
   std::vector<pappso::XicCoordSPtr> mass_list;
   for(XicBoxNaturalIsotope &xic_isotope : _natural_isotope_list)
@@ -800,13 +798,17 @@ XicBox::reExtractXic()
         xic_coord_ref.get()->initializeAndClone();
       xic_coord.get()->mzRange =
         pappso::MzRange(xic_isotope.peptide_natural_isotope_sp.get()->getMz(),
-                        _p_xic_window->getXicExtractPrecision());
+                        params.get()->xic_extraction_range);
       mass_list.push_back(xic_coord);
       xic_isotope.xic_sp = xic_coord.get()->xicSptr;
     }
 
   qDebug();
-  emit loadXic(_msrun_sp, mass_list, pappso::XicExtractMethod::max);
+  emit loadXic(_msrun_sp, mass_list,
+               _p_xic_window->getProjectWindow()
+                 ->getProjectSP()
+                 .get()
+                 ->getMasschroqFileParametersSp());
 
   qDebug();
 }
@@ -883,16 +885,15 @@ XicBox::onIsotopicDistributionClick()
 
 void
 XicBox::addCommonRt(std::vector<std::size_t> &common_peak_rt_measure_list,
-                    const pappso::TracePeak *peak,
-                    const pappso::Xic *xic) const
+                    const pappso::TracePeak *peak, const pappso::Xic *xic) const
 {
 
   if(common_peak_rt_measure_list.size() == 0)
     { // no common peaks, filling with whole peak
-      auto it = pappso::findFirstEqualOrGreaterX(
-        xic->begin(), xic->end(), peak->getLeftBoundary().x);
-      auto itend = pappso::findFirstGreaterX(
-        xic->begin(), xic->end(), peak->getRightBoundary().x);
+      auto it    = pappso::findFirstEqualOrGreaterX(xic->begin(), xic->end(),
+                                                 peak->getLeftBoundary().x);
+      auto itend = pappso::findFirstGreaterX(xic->begin(), xic->end(),
+                                             peak->getRightBoundary().x);
 
       std::size_t i = it - xic->begin();
 
@@ -910,10 +911,10 @@ XicBox::addCommonRt(std::vector<std::size_t> &common_peak_rt_measure_list,
     {
       std::vector<std::size_t> intersect(common_peak_rt_measure_list);
       std::vector<std::size_t> new_rt;
-      auto it = pappso::findFirstEqualOrGreaterX(
-        xic->begin(), xic->end(), peak->getLeftBoundary().x);
-      auto itend = pappso::findFirstGreaterX(
-        xic->begin(), xic->end(), peak->getRightBoundary().x);
+      auto it    = pappso::findFirstEqualOrGreaterX(xic->begin(), xic->end(),
+                                                 peak->getLeftBoundary().x);
+      auto itend = pappso::findFirstGreaterX(xic->begin(), xic->end(),
+                                             peak->getRightBoundary().x);
 
       std::size_t i = it - xic->begin();
       while(it != itend)
@@ -926,10 +927,8 @@ XicBox::addCommonRt(std::vector<std::size_t> &common_peak_rt_measure_list,
           i++;
         }
 
-      auto itinter = std::set_intersection(intersect.begin(),
-                                           intersect.end(),
-                                           new_rt.begin(),
-                                           new_rt.end(),
+      auto itinter = std::set_intersection(intersect.begin(), intersect.end(),
+                                           new_rt.begin(), new_rt.end(),
                                            common_peak_rt_measure_list.begin());
       common_peak_rt_measure_list.resize(itinter -
                                          common_peak_rt_measure_list.begin());
