@@ -76,13 +76,12 @@ class XicBox : public QWidget
 
   void rescaleXicWidget(QString axis_name, QCPRange intensity_range);
   QCPRange getRtRange();
-  ZivyParams getZivyParamsUsed();
   void showLoadingIcon(bool loading_status);
 
   signals:
   void loadXic(MsRunSp p_msrun,
                std::vector<pappso::XicCoordSPtr> mz_list,
-               pappso::XicExtractMethod method);
+               MasschroqFileParametersSp masschroq_params_sp);
   void computeIsotopeMassList(pappso::PeptideSp peptide_sp,
                               unsigned int charge,
                               pappso::PrecisionPtr precision,
