@@ -27,13 +27,13 @@
  *implementation
  ******************************************************************************/
 
-#ifndef ZIVYDIALOG_H
-#define ZIVYDIALOG_H
+#pragma once
 
 #include <QDialogButtonBox>
 #include <QDialog>
 #include "zivywidget.h"
 #include "xicexportparam.h"
+#include "../../../core/masschroq_run/masschroqfileparameters.h"
 
 class ZivyDialog : public QDialog
 {
@@ -44,16 +44,16 @@ class ZivyDialog : public QDialog
   virtual ~ZivyDialog();
 
 
-  void setZivyParams(const ZivyParams &params);
-  const ZivyParams getZivyParams() const;
+  void setMasschroqFileParametersSp(const MasschroqFileParametersSp &params);
+  void updateProjectMasschroqFileParameters() const;
 
   void setXicExportParams();
   void saveXicExportSettings();
 
   private:
+  QLabel *_p_display_filters;
   ZivyWidget *_p_zivy_widget;
   XicExportWidget *mp_xicExportWidget;
   QDialogButtonBox *_p_button_box;
+  MasschroqFileParametersSp msp_MasschroqFileParametersSp;
 };
-
-#endif // ZIVYDIALOG_H
