@@ -403,7 +403,7 @@ PepXmlSaxHandler::startElement_search_hit(QXmlAttributes attributes)
     PeptideXtp(attributes.value("peptide").simplified()).makePeptideXtpSp();
 
 
-  _p_peptide_evidence = new PeptideEvidence(_sp_msrun.get(), _scan);
+  _p_peptide_evidence = new PeptideEvidence(_sp_msrun.get(), _scan, false);
 
   _p_peptide_evidence->setRetentionTime(_current_retention_time);
   _p_peptide_evidence->setCharge(_current_charge);
