@@ -620,7 +620,8 @@ XtandemSaxHandler::endElement_note()
 
       if(_current_note_label == "spectrum, path")
         {
-          _sp_msrun.get()->setFileName(_current_text);
+          //_sp_msrun.get()->setFileName(_current_text);
+          // already set by tandem info parser
         }
 
       /*
