@@ -654,21 +654,23 @@ XtpXpipSaxHandler::startElement_msrunInAlignmentGroup(QXmlAttributes attributes)
 bool
 XtpXpipSaxHandler::startElement_alignment_param(QXmlAttributes attributes)
 {
-  m_massChroQFileParams.ms2_tendency_half_window =
+  MasschroqFileParameters *p_masschroq_file_params =
+    _p_project->getMasschroqFileParametersSp().get();
+  p_masschroq_file_params->ms2_tendency_half_window =
     attributes.value("ms2_tendency").toInt();
-  m_massChroQFileParams.ms2_smoothing_half_window =
+  p_masschroq_file_params->ms2_smoothing_half_window =
     attributes.value("ms2_smoothing").toInt();
-  m_massChroQFileParams.ms1_smoothing_half_window =
+  p_masschroq_file_params->ms1_smoothing_half_window =
     attributes.value("ms1_smoothing").toInt();
   if(!attributes.value("time_corrections").simplified().isEmpty())
     {
-      m_massChroQFileParams.write_alignment_times = true;
-      m_massChroQFileParams.alignment_times_directory =
+      p_masschroq_file_params->write_alignment_times = true;
+      p_masschroq_file_params->alignment_times_directory =
         attributes.value("time_corrections").simplified();
     }
   else
     {
-      m_massChroQFileParams.write_alignment_times = false;
+      p_masschroq_file_params->write_alignment_times = false;
     }
   return true;
 }
@@ -676,19 +678,22 @@ XtpXpipSaxHandler::startElement_alignment_param(QXmlAttributes attributes)
 bool
 XtpXpipSaxHandler::startElement_masschroq_param(QXmlAttributes attributes)
 {
+
+  MasschroqFileParameters *p_masschroq_file_params =
+    _p_project->getMasschroqFileParametersSp().get();
   msp_alignment_group->setMassChroqmlPath(attributes.value("masschroqml"));
   if(QFileInfo(attributes.value("result")).suffix() == "ods")
     {
-      m_massChroQFileParams.result_file_format = TableFileFormat::ods;
+      p_masschroq_file_params->result_file_format = TableFileFormat::ods;
     }
   else
     {
-      m_massChroQFileParams.result_file_format = TableFileFormat::tsv;
+      p_masschroq_file_params->result_file_format = TableFileFormat::tsv;
     }
 
   if(!attributes.value("compar").isEmpty())
     {
-      m_massChroQFileParams.export_compar_file = true;
+      p_masschroq_file_params->export_compar_file = true;
     }
   return true;
 }
@@ -696,26 +701,31 @@ XtpXpipSaxHandler::startElement_masschroq_param(QXmlAttributes attributes)
 bool
 XtpXpipSaxHandler::startElement_quantification_param(QXmlAttributes attributes)
 {
-  m_massChroQFileParams.xic_extraction_range =
+  MasschroqFileParameters *p_masschroq_file_params =
+    _p_project->getMasschroqFileParametersSp().get();
+  p_masschroq_file_params->xic_extraction_range =
     pappso::PrecisionFactory::fromString(attributes.value("xic_range"));
   if(attributes.value("xic_method").toInt() == 0)
     {
-      m_massChroQFileParams.xic_extraction_method =
+      p_masschroq_file_params->xic_extraction_method =
         pappso::XicExtractMethod::max;
     }
   else
     {
-      m_massChroQFileParams.xic_extraction_method =
+      p_masschroq_file_params->xic_extraction_method =
         pappso::XicExtractMethod::sum;
     }
 
-  ZivyParams zivy;
-  zivy._smoothing_half_window = attributes.value("smoothing").toInt();
-  zivy._minmax_half_window    = attributes.value("minmax_half").toInt();
-  zivy._maxmin_half_window    = attributes.value("maxmin_half").toInt();
-  zivy._minmax_threshold      = attributes.value("minmax_thre").toDouble();
-  zivy._maxmin_threshold      = attributes.value("maxmin_thre").toDouble();
-  msp_alignment_group->setZivyParams(zivy);
+  p_masschroq_file_params->m_zivyParams._smoothing_half_window =
+    attributes.value("smoothing").toInt();
+  p_masschroq_file_params->m_zivyParams._minmax_half_window =
+    attributes.value("minmax_half").toInt();
+  p_masschroq_file_params->m_zivyParams._maxmin_half_window =
+    attributes.value("maxmin_half").toInt();
+  p_masschroq_file_params->m_zivyParams._minmax_threshold =
+    attributes.value("minmax_thre").toDouble();
+  p_masschroq_file_params->m_zivyParams._maxmin_threshold =
+    attributes.value("maxmin_thre").toDouble();
   return true;
 }
 
@@ -1008,7 +1018,6 @@ XtpXpipSaxHandler::endElement_msrun()
 bool
 XtpXpipSaxHandler::endElement_alignmentGroup()
 {
-  msp_alignment_group->setMassChroQFileParams(m_massChroQFileParams);
   msp_alignment_group = nullptr;
   return true;
 }
