@@ -91,8 +91,6 @@ MassChroQml::MassChroQml(const QString &out_filename,
 
   _output_stream->setAutoFormatting(true);
   _output_stream->writeStartDocument("1.0");
-
-  _detect_zivy.loadSettings();
 }
 
 MassChroQml::~MassChroQml()
@@ -251,9 +249,8 @@ MassChroQml::writeQuantificationTraces()
   _output_stream->writeStartElement("quantification_traces");
   //<peptide_traces peptide_ids="pep0 pep1" output_dir="pep_traces"
   //	format="tsv" />
-  _output_stream->writeComment(
-    "<peptide_traces peptide_ids=\"pep0 pep1\" "
-    "output_dir=\"pep_traces\" format=\"tsv\" />");
+  _output_stream->writeComment("<peptide_traces peptide_ids=\"pep0 pep1\" "
+                               "output_dir=\"pep_traces\" format=\"tsv\" />");
   /*
       <all_xics_traces output_dir="all_xics_traces" format="tsv" />
       <mz_traces mz_values="634.635 449.754 552.234" output_dir="mz_traces"
@@ -305,9 +302,8 @@ MassChroQml::writeQuantify()
         }
       _output_stream->writeEndElement();
 
-      _output_stream->writeComment(
-        "<mz_list>732.317 449.754 552.234 464.251 "
-        "381.577 569.771 575.256</mz_list>");
+      _output_stream->writeComment("<mz_list>732.317 449.754 552.234 464.251 "
+                                   "381.577 569.771 575.256</mz_list>");
       _output_stream->writeComment(
         "<mzrt_list>\n				<mzrt mz=\"732.317\" rt=\"230.712\" />\n			"
         "<mzrt "
@@ -366,17 +362,8 @@ MassChroQml::writeQuantificationMethods()
   _output_stream->writeEndElement();
   //</xic_extraction>
   _output_stream->writeEndElement();
-  //<xic_filters>
-  _output_stream->writeStartElement("xic_filters");
-  //<anti_spike half="5"/>
-  _output_stream->writeStartElement("anti_spike");
-  _output_stream->writeAttribute("half", "5");
-  _output_stream->writeEndElement();
-  //<background half_mediane="5" half_min_max="20"/>
-  _output_stream->writeComment(
-    "<background half_mediane=\"5\" half_min_max=\"20\"/>");
-  //</xic_filters>
-  _output_stream->writeEndElement();
+
+  writeXicFilters();
   //<peak_detection>
 
   _output_stream->writeStartElement("peak_detection");
@@ -385,27 +372,27 @@ MassChroQml::writeQuantificationMethods()
   //<mean_filter_half_edge>1</mean_filter_half_edge>
   _output_stream->writeStartElement("mean_filter_half_edge");
   _output_stream->writeCharacters(
-    QString("%1").arg(_detect_zivy._smoothing_half_window));
+    QString("%1").arg(m_params.m_zivyParams._smoothing_half_window));
   _output_stream->writeEndElement();
   //<minmax_half_edge>3</minmax_half_edge>
   _output_stream->writeStartElement("minmax_half_edge");
   _output_stream->writeCharacters(
-    QString("%1").arg(_detect_zivy._minmax_half_window));
+    QString("%1").arg(m_params.m_zivyParams._minmax_half_window));
   _output_stream->writeEndElement();
   //<maxmin_half_edge>2</maxmin_half_edge>
   _output_stream->writeStartElement("maxmin_half_edge");
   _output_stream->writeCharacters(
-    QString("%1").arg(_detect_zivy._maxmin_half_window));
+    QString("%1").arg(m_params.m_zivyParams._maxmin_half_window));
   _output_stream->writeEndElement();
   //<detection_threshold_on_max>5000</detection_threshold_on_max>
   _output_stream->writeStartElement("detection_threshold_on_max");
   _output_stream->writeCharacters(
-    QString("%1").arg(_detect_zivy._minmax_threshold));
+    QString("%1").arg(m_params.m_zivyParams._minmax_threshold));
   _output_stream->writeEndElement();
   //<detection_threshold_on_min>3000</detection_threshold_on_min>
   _output_stream->writeStartElement("detection_threshold_on_min");
   _output_stream->writeCharacters(
-    QString("%1").arg(_detect_zivy._maxmin_threshold));
+    QString("%1").arg(m_params.m_zivyParams._maxmin_threshold));
   _output_stream->writeEndElement();
   //</detection_zivy>
   _output_stream->writeEndElement();
@@ -562,8 +549,7 @@ MassChroQml::writePeptideListInGroup(const GroupingGroup *p_group)
     }
 
   // sort list
-  std::sort(mcq_peptide_list.begin(),
-            mcq_peptide_list.end(),
+  std::sort(mcq_peptide_list.begin(), mcq_peptide_list.end(),
             [](const McqPeptide &first, const McqPeptide &second) {
               return (first.id < second.id);
             });
@@ -649,8 +635,7 @@ MassChroQml::writePeptideListInGroup(const GroupingGroup *p_group)
         }
 
       //<observed_in data="samp0" scan="655" z="2" />
-      std::sort(mcq_peptide.observed_in.begin(),
-                mcq_peptide.observed_in.end(),
+      std::sort(mcq_peptide.observed_in.begin(), mcq_peptide.observed_in.end(),
                 [](const McqObserved &first, const McqObserved &second) {
                   return std::tie(first.charge, first.scan, first.msrun) <
                          std::tie(second.charge, second.scan, second.msrun);
@@ -681,7 +666,22 @@ MassChroQml::writeGroups()
   //<groups>
   _output_stream->writeStartElement("groups");
   //<group data_ids="samp0 samp1" id="G1" />
-  for(MsRunAlignmentGroupSp group_sp : m_params.alignment_groups)
+  std::vector<MsRunAlignmentGroupSp> alignment_groups_copy =
+    m_params.alignment_groups;
+  std::sort(alignment_groups_copy.begin(), alignment_groups_copy.end(),
+            [](const MsRunAlignmentGroupSp &g1, MsRunAlignmentGroupSp &g2) {
+              return g1.get()->getMsRunAlignmentGroupName() <
+                     g2.get()->getMsRunAlignmentGroupName();
+            });
+  auto it =
+    std::unique(alignment_groups_copy.begin(), alignment_groups_copy.end(),
+                [](const MsRunAlignmentGroupSp &g1, MsRunAlignmentGroupSp &g2) {
+                  return g1.get()->getMsRunAlignmentGroupName() ==
+                         g2.get()->getMsRunAlignmentGroupName();
+                });
+  alignment_groups_copy.erase(it, alignment_groups_copy.end());
+
+  for(MsRunAlignmentGroupSp group_sp : alignment_groups_copy)
     {
       _output_stream->writeStartElement("group");
       _output_stream->writeAttribute("id",
@@ -743,3 +743,55 @@ MassChroQml::writeProteinList()
   //</protein_list>
   _output_stream->writeEndElement();
 }
+
+
+void
+MassChroQml::writeXicFilters()
+{
+
+  //<xic_filters>
+  _output_stream->writeStartElement("xic_filters");
+
+  if(m_params.msp_xicFilterSuiteString.get() == nullptr)
+    {
+      //<anti_spike half="5"/> by default
+      _output_stream->writeStartElement("anti_spike");
+      _output_stream->writeAttribute("half", "5");
+      _output_stream->writeEndElement();
+    }
+  else
+    {
+      for(auto &filter_sp : *(m_params.msp_xicFilterSuiteString.get()))
+        {
+          if(filter_sp.get()->name() == "antiSpike")
+            {
+              _output_stream->writeStartElement("anti_spike");
+              _output_stream->writeAttribute(
+                "half", filter_sp.get()->toString().replace("antiSpike|", ""));
+              _output_stream->writeEndElement();
+            }
+          else if(filter_sp.get()->name() == "passQuantileBasedRemoveY")
+            {
+              // passQuantileBasedRemoveY
+              _output_stream->writeStartElement("remove_quantile");
+              _output_stream->writeAttribute(
+                "value", filter_sp.get()->toString().replace(
+                           "passQuantileBasedRemoveY|", ""));
+              _output_stream->writeEndElement();
+            }
+          else
+            {
+
+              throw pappso::PappsoException(
+                QObject::tr("Error writing MassChroqML file :\n unable to "
+                            "write xic filer %1")
+                  .arg(filter_sp.get()->toString()));
+            }
+        }
+    }
+  //<background half_mediane="5" half_min_max="20"/>
+  _output_stream->writeComment(
+    "<background half_mediane=\"5\" half_min_max=\"20\"/>");
+  //</xic_filters>
+  _output_stream->writeEndElement();
+}
