@@ -41,20 +41,68 @@
 #include <QSettings>
 #include <grantlee/template.h>
 #include <grantlee/engine.h>
+#include <QTemporaryDir>
 
 
-McqrRdata::McqrRdata(QString rdata_file_path, ProjectSp project)
+McqrRdata::McqrRdata(McqrExperimentSp mcqr_experiment_sp, ProjectSp project)
 {
-  msp_project    = project;
-  m_rdataFile    = open(rdata_file_path.toUtf8(), O_CREAT | O_WRONLY, 0664);
-  mp_rdataWriter = rdata_writer_init(&write_data, RDATA_WORKSPACE);
-  rdata_begin_file(mp_rdataWriter, &m_rdataFile);
+  msp_project        = project;
+  msp_mcqrExperiment = mcqr_experiment_sp;
 }
 
 McqrRdata::~McqrRdata()
 {
 }
 
+
+void
+McqrRdata::writeSpectralCountData(pappso::UiMonitorInterface &monitor)
+{
+
+  // mcqr_experiment_sp.get()->getRdataFilePath();
+  QString rdata_dir =
+    QFileInfo(msp_mcqrExperiment.get()->getRdataFilePath()).absolutePath();
+  qDebug() << " rdata_path=" << msp_mcqrExperiment.get()->getRdataFilePath();
+  QTemporaryDir *tmp_rdata_dir_p = new QTemporaryDir(rdata_dir + "/output");
+  tmp_rdata_dir_p->setAutoRemove(true);
+
+  if(!tmp_rdata_dir_p->isValid())
+    {
+      throw pappso::PappsoException(
+        QObject::tr(
+          "problem creating Rdata writing temporary directory in %1\n")
+          .arg(rdata_dir));
+    }
+
+  monitor.setTitle(QObject::tr("writing MCQR metadata file, please wait"));
+
+  QFileInfo meta_rdata_path(tmp_rdata_dir_p->path() + "/meta.RData");
+  writeMetaDataTable(meta_rdata_path);
+
+
+  monitor.setTitle(QObject::tr("writing MCQR summary file, please wait"));
+  QFileInfo summary_rdata_path(tmp_rdata_dir_p->path() + "/summary.RData");
+  writeExperimentalSummaryTable(summary_rdata_path);
+
+  monitor.setTitle(
+    QObject::tr("writing MCQR spectral count file, please wait"));
+  QFileInfo sc_rdata_path(tmp_rdata_dir_p->path() + "/sc.RData");
+  writeSpectraCountTable(sc_rdata_path);
+
+  monitor.setTitle(
+    QObject::tr("writing MCQR quantification info file, please wait"));
+  QFileInfo quanti_rdata_path(tmp_rdata_dir_p->path() + "/quanti.RData");
+  writeQuantiInfoTable(quanti_rdata_path);
+
+  monitor.setTitle(QObject::tr("Merging MCQR rdata files, please wait"));
+  QString rscript_path = McqrRdata::createTheMergeRScript(
+    tmp_rdata_dir_p->path(), msp_mcqrExperiment.get()->getRdataFilePath(),
+    msp_mcqrExperiment.get()->getMassChroqMlFilePath());
+  McqrRdata::mergeTheRDataFiles(rscript_path);
+  tmp_rdata_dir_p->remove();
+}
+
+
 ssize_t
 McqrRdata::write_data(const void *bytes, size_t len, void *ctx)
 {
@@ -71,8 +119,15 @@ McqrRdata::closeMCQRDataFile()
 
 
 void
-McqrRdata::writeMetaDataTable()
+McqrRdata::writeMetaDataTable(const QFileInfo &meta_datafile)
 {
+
+  m_rdataFile =
+    open(meta_datafile.absoluteFilePath().toUtf8(), O_CREAT | O_WRONLY, 0664);
+  mp_rdataWriter = rdata_writer_init(&write_data, RDATA_WORKSPACE);
+  rdata_begin_file(mp_rdataWriter, &m_rdataFile);
+
+
   std::vector<McqrMetadata *> metadata_lines =
     msp_project->getMcqrExperimentSp().get()->getmetadataInfoVector();
   std::vector<QString> colnames =
@@ -141,6 +196,8 @@ McqrRdata::writeMetaDataTable()
       rdata_end_column(mp_rdataWriter, column_writer);
     }
   rdata_end_table(mp_rdataWriter, metadata_lines.size(), "Metadata info");
+
+  closeMCQRDataFile();
 }
 
 std::vector<rdata_column_t *>
@@ -155,8 +212,8 @@ McqrRdata::createMetadataColumns()
       rdata_column_t *col_writer;
       if(col_name == "msrun" || col_name == "msrunfile")
         {
-          col_writer = rdata_add_column(
-            mp_rdataWriter, col_name.toUtf8(), RDATA_TYPE_STRING);
+          col_writer = rdata_add_column(mp_rdataWriter, col_name.toUtf8(),
+                                        RDATA_TYPE_STRING);
         }
       else
         {
@@ -170,20 +227,20 @@ McqrRdata::createMetadataColumns()
           if(type == QVariant::Type::Double)
             {
               qDebug() << "double : " << col_name;
-              col_writer = rdata_add_column(
-                mp_rdataWriter, col_name.toUtf8(), RDATA_TYPE_REAL);
+              col_writer = rdata_add_column(mp_rdataWriter, col_name.toUtf8(),
+                                            RDATA_TYPE_REAL);
             }
           else if(type == QVariant::Type::Bool)
             {
               qDebug() << "bool : " << col_name;
-              col_writer = rdata_add_column(
-                mp_rdataWriter, col_name.toUtf8(), RDATA_TYPE_LOGICAL);
+              col_writer = rdata_add_column(mp_rdataWriter, col_name.toUtf8(),
+                                            RDATA_TYPE_LOGICAL);
             }
           else if(type == QVariant::Type::String)
             {
               qDebug() << "string : " << col_name;
-              col_writer = rdata_add_column(
-                mp_rdataWriter, col_name.toUtf8(), RDATA_TYPE_STRING);
+              col_writer = rdata_add_column(mp_rdataWriter, col_name.toUtf8(),
+                                            RDATA_TYPE_STRING);
             }
           else
             {
@@ -197,9 +254,14 @@ McqrRdata::createMetadataColumns()
 }
 
 void
-McqrRdata::writeSpectraCountTable()
+McqrRdata::writeSpectraCountTable(const QFileInfo &sctable_datafile)
 {
 
+  m_rdataFile    = open(sctable_datafile.absoluteFilePath().toUtf8(),
+                     O_CREAT | O_WRONLY, 0664);
+  mp_rdataWriter = rdata_writer_init(&write_data, RDATA_WORKSPACE);
+  rdata_begin_file(mp_rdataWriter, &m_rdataFile);
+
   rdata_column_t *col_protein =
     rdata_add_column(mp_rdataWriter, "protein", RDATA_TYPE_STRING);
   rdata_column_t *col_msrun =
@@ -230,8 +292,7 @@ McqrRdata::writeSpectraCountTable()
               group_pair.second.get()->getProteinMatchList())
             {
               for(std::size_t i = 0;
-                  i < msp_project->getMsRunStore().getMsRunList().size();
-                  i++)
+                  i < msp_project->getMsRunStore().getMsRunList().size(); i++)
                 {
                   QString protein_id =
                     protein_match->getGrpProteinSp().get()->getGroupingId();
@@ -249,10 +310,10 @@ McqrRdata::writeSpectraCountTable()
   rdata_begin_column(mp_rdataWriter, col_msrun, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
-          for(const ProteinMatch *protein_match :
+          for(const ProteinMatch *protein_match [[maybe_unused]] :
               group_pair.second.get()->getProteinMatchList())
             {
               for(MsRunSp msrun_sp :
@@ -270,10 +331,10 @@ McqrRdata::writeSpectraCountTable()
   rdata_begin_column(mp_rdataWriter, col_msrunfile, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
-          for(const ProteinMatch *protein_match :
+          for(const ProteinMatch *protein_match [[maybe_unused]] :
               group_pair.second.get()->getProteinMatchList())
             {
               for(MsRunSp msrun_sp :
@@ -291,15 +352,14 @@ McqrRdata::writeSpectraCountTable()
   rdata_begin_column(mp_rdataWriter, col_acc, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
               group_pair.second.get()->getProteinMatchList())
             {
               for(std::size_t i = 0;
-                  i < msp_project->getMsRunStore().getMsRunList().size();
-                  i++)
+                  i < msp_project->getMsRunStore().getMsRunList().size(); i++)
                 {
                   QString protein_acc =
                     protein_match->getProteinXtpSp()->getAccession();
@@ -315,15 +375,14 @@ McqrRdata::writeSpectraCountTable()
   rdata_begin_column(mp_rdataWriter, col_desc, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
               group_pair.second.get()->getProteinMatchList())
             {
               for(std::size_t i = 0;
-                  i < msp_project->getMsRunStore().getMsRunList().size();
-                  i++)
+                  i < msp_project->getMsRunStore().getMsRunList().size(); i++)
                 {
                   QString protein_desc =
                     protein_match->getProteinXtpSp()->getDescription();
@@ -339,7 +398,7 @@ McqrRdata::writeSpectraCountTable()
   rdata_begin_column(mp_rdataWriter, col_sc, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
@@ -361,7 +420,7 @@ McqrRdata::writeSpectraCountTable()
   rdata_begin_column(mp_rdataWriter, col_specific_sc, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
@@ -370,12 +429,12 @@ McqrRdata::writeSpectraCountTable()
               for(MsRunSp ms_runsp :
                   msp_project->getMsRunStore().getMsRunList())
                 {
-                  std::size_t protein_sc = protein_match->getGroupingGroupSp()
-                                             .get()
-                                             ->countSpecificSampleScan(
-                                               protein_match,
-                                               ValidationState::validAndChecked,
-                                               ms_runsp.get());
+                  std::size_t protein_sc =
+                    protein_match->getGroupingGroupSp()
+                      .get()
+                      ->countSpecificSampleScan(
+                        protein_match, ValidationState::validAndChecked,
+                        ms_runsp.get());
                   rdata_append_real_value(mp_rdataWriter, protein_sc);
                 }
             }
@@ -383,6 +442,8 @@ McqrRdata::writeSpectraCountTable()
     }
   rdata_end_column(mp_rdataWriter, col_specific_sc);
   rdata_end_table(mp_rdataWriter, row_count, "Spectral count data");
+
+  closeMCQRDataFile();
 }
 
 std::size_t
@@ -391,7 +452,7 @@ McqrRdata::getNumberOfRow(bool is_spectral_count)
   std::size_t row_count = 0;
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           std::size_t nb_msrun;
@@ -412,8 +473,14 @@ McqrRdata::getNumberOfRow(bool is_spectral_count)
 }
 
 void
-McqrRdata::writeQuantiInfoTable()
+McqrRdata::writeQuantiInfoTable(const QFileInfo &quanti_info_datafile)
 {
+  m_rdataFile    = open(quanti_info_datafile.absoluteFilePath().toUtf8(),
+                     O_CREAT | O_WRONLY, 0664);
+  mp_rdataWriter = rdata_writer_init(&write_data, RDATA_WORKSPACE);
+  rdata_begin_file(mp_rdataWriter, &m_rdataFile);
+
+
   rdata_column_t *col_protein =
     rdata_add_column(mp_rdataWriter, "accession", RDATA_TYPE_STRING);
   rdata_column_t *col_nbaa =
@@ -430,7 +497,7 @@ McqrRdata::writeQuantiInfoTable()
   rdata_begin_column(mp_rdataWriter, col_protein, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
@@ -448,7 +515,7 @@ McqrRdata::writeQuantiInfoTable()
   rdata_begin_column(mp_rdataWriter, col_nbaa, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
@@ -465,7 +532,7 @@ McqrRdata::writeQuantiInfoTable()
   rdata_begin_column(mp_rdataWriter, col_nbpepth, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
@@ -483,7 +550,7 @@ McqrRdata::writeQuantiInfoTable()
   rdata_begin_column(mp_rdataWriter, col_mass, row_count);
   for(IdentificationGroup *ident : msp_project->getIdentificationGroupList())
     {
-      for(const std::pair<unsigned int, GroupingGroupSp> &group_pair :
+      for(const std::pair<unsigned int, GroupingGroupSp> group_pair :
           ident->getGroupStore().getGroupMap())
         {
           for(const ProteinMatch *protein_match :
@@ -497,11 +564,21 @@ McqrRdata::writeQuantiInfoTable()
   rdata_end_column(mp_rdataWriter, col_mass);
 
   rdata_end_table(mp_rdataWriter, row_count, "Quantification info data");
+
+
+  closeMCQRDataFile();
 }
 
 void
-McqrRdata::writeExperimentalSummaryTable()
+McqrRdata::writeExperimentalSummaryTable(
+  const QFileInfo &experimental_summary_datafile)
 {
+
+  m_rdataFile = open(experimental_summary_datafile.absoluteFilePath().toUtf8(),
+                     O_CREAT | O_WRONLY, 0664);
+  mp_rdataWriter = rdata_writer_init(&write_data, RDATA_WORKSPACE);
+  rdata_begin_file(mp_rdataWriter, &m_rdataFile);
+
   McqrExpSummary summary =
     msp_project->getMcqrExperimentSp().get()->getMcqrExpSummary();
   rdata_column_t *col_attribute =
@@ -536,6 +613,8 @@ McqrRdata::writeExperimentalSummaryTable()
                             summary.m_quantificationMethod.toUtf8());
   rdata_end_column(mp_rdataWriter, col_value);
   rdata_end_table(mp_rdataWriter, row_number, "Experimental summary data");
+
+  closeMCQRDataFile();
 }
 
 std::size_t
@@ -596,17 +675,23 @@ void
 McqrRdata::mergeTheRDataFiles(const QString script_path)
 {
   QSettings settings;
-  QString r_path = settings.value("mcqr/r_path", "/usr/bin/Rscript").toString();
+  QString rscript_binary_path =
+    settings.value("path/rscript_binary", "Rscript").toString();
   QStringList script_path_param;
   script_path_param << script_path;
 
   QProcess *r_process = new QProcess();
-  r_process->start(r_path, script_path_param);
+  r_process->start(rscript_binary_path, script_path_param);
 
   if(!r_process->waitForStarted())
     {
-      throw pappso::PappsoException(
-        QObject::tr("Merge RData R process failed to start"));
+      QString err =
+        QObject::tr(
+          "Could not start Rscript process '%1' with arguments '%2': %3")
+          .arg(rscript_binary_path)
+          .arg(script_path_param.join(QStringLiteral(" ")))
+          .arg(r_process->errorString());
+      throw pappso::PappsoException(err);
     }
 
   while(r_process->waitForReadyRead())
@@ -627,7 +712,7 @@ McqrRdata::mergeTheRDataFiles(const QString script_path)
       delete r_process;
       throw pappso::PappsoException(
         QObject::tr("error executing R process Status != 0 : %1 %2\n%3")
-          .arg(r_path)
+          .arg(rscript_binary_path)
           .arg(script_path_param.join(" ").arg(result.data())));
     }
 }
