@@ -28,8 +28,7 @@
  *implementation
  ******************************************************************************/
 
-#ifndef MCQRSCPEPTIDE_H
-#define MCQRSCPEPTIDE_H
+#pragma once
 
 #include <odsstream/calcwriterinterface.h>
 #include "../../core/project.h"
@@ -64,5 +63,3 @@ class McqRscPeptide
   const Project *_p_project;
   CalcWriterInterface *_p_writer;
 };
-
-#endif // MCQRSCPEPTIDE_H
