@@ -49,6 +49,7 @@
 #include <QSettings>
 #include <odsstream/odsexception.h>
 #include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/exception/exceptioninterrupted.h>
 
 OdsExport::OdsExport(ProjectSp project) : _p_project(project)
 {
@@ -88,7 +89,7 @@ OdsExport::write(CalcWriterInterface *p_writer, WorkMonitorInterface *p_monitor)
         }
       if(settings.value("export_ods/simple", "false").toBool())
         {
-          SimpleSheet(p_writer, _p_project.get());
+          SimpleSheet(p_writer, _p_project.get(), p_monitor->getSubMonitor());
         }
       if(settings.value("export_ods/proteins", "true").toBool())
         {
@@ -100,10 +101,14 @@ OdsExport::write(CalcWriterInterface *p_writer, WorkMonitorInterface *p_monitor)
           p_monitor->message(QObject::tr("writing peptides"));
           PeptideSheet(this, p_writer, _p_project.get());
         }
+      bool mobility_informations =
+        settings.value("export_ods/spectra_mobility_informations", "false")
+          .toBool();
       if(settings.value("export_ods/spectra", "true").toBool())
         {
           p_monitor->message(QObject::tr("writing spectra"));
-          SpectraSheet(this, p_writer, _p_project.get());
+          qDebug() << " mobility_informations=" << mobility_informations;
+          SpectraSheet(this, p_writer, _p_project.get(), mobility_informations);
         }
       if(settings.value("export_ods/psm", "true").toBool())
         {
@@ -140,21 +145,25 @@ OdsExport::write(CalcWriterInterface *p_writer, WorkMonitorInterface *p_monitor)
           if(settings.value("export_ods/comparspectra", "true").toBool())
             {
               p_monitor->message(QObject::tr("writing spectra comparisons"));
-              ComparSpectraSheet(this, p_writer, _p_project.get()).writeSheet();
+              ComparSpectraSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
+                .writeSheet();
             }
           if(settings.value("export_ods/comparspecificspectra", "true")
                .toBool())
             {
               p_monitor->message(
                 QObject::tr("writing specific spectra comparisons"));
-              ComparSpecificSpectraSheet(this, p_writer, _p_project.get())
+              ComparSpecificSpectraSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
                 .writeSheet();
             }
           if(settings.value("export_ods/comparuniquesequence", "true").toBool())
             {
               p_monitor->message(
                 QObject::tr("writing unique sequence comparisons"));
-              ComparSequenceSheet(this, p_writer, _p_project.get())
+              ComparSequenceSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
                 .writeSheet();
             }
           if(settings.value("export_ods/comparspecificuniquesequence", "true")
@@ -162,23 +171,30 @@ OdsExport::write(CalcWriterInterface *p_writer, WorkMonitorInterface *p_monitor)
             {
               p_monitor->message(
                 QObject::tr("writing specific unique sequence comparisons"));
-              ComparSpecificSequenceSheet(this, p_writer, _p_project.get())
+              ComparSpecificSequenceSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
                 .writeSheet();
             }
           if(settings.value("export_ods/comparpai", "true").toBool())
             {
               p_monitor->message(QObject::tr("writing PAI comparisons"));
-              ComparPaiSheet(this, p_writer, _p_project.get()).writeSheet();
+              ComparPaiSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
+                .writeSheet();
             }
           if(settings.value("export_ods/comparempai", "true").toBool())
             {
               p_monitor->message(QObject::tr("writing emPAI comparisons"));
-              ComparEmpaiSheet(this, p_writer, _p_project.get()).writeSheet();
+              ComparEmpaiSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
+                .writeSheet();
             }
           if(settings.value("export_ods/comparnsaf", "true").toBool())
             {
               p_monitor->message(QObject::tr("writing NSAF comparisons"));
-              ComparNsafSheet(this, p_writer, _p_project.get()).writeSheet();
+              ComparNsafSheet(
+                this, p_writer, _p_project.get(), p_monitor->getSubMonitor())
+                .writeSheet();
             }
         }
       if(settings.value("export_ods/samples", "true").toBool())
@@ -207,6 +223,12 @@ OdsExport::write(CalcWriterInterface *p_writer, WorkMonitorInterface *p_monitor)
             }
         }
     }
+  catch(pappso::ExceptionInterrupted &error)
+    {
+      throw pappso::PappsoException(
+        QObject::tr("ODS file not completed, interrupted by the user:\n %1")
+          .arg(error.qwhat()));
+    }
   catch(OdsException &error)
     {
       throw pappso::PappsoException(
