@@ -549,8 +549,7 @@ ProticdbMl::writepeptideHitsbyGroup(GroupingGroup *p_group)
           protic_peptide_hit_list.push_back(protic_peptide_hit);
         }
     }
-  std::sort(protic_peptide_hit_list.begin(),
-            protic_peptide_hit_list.end(),
+  std::sort(protic_peptide_hit_list.begin(), protic_peptide_hit_list.end(),
             [](const ProticPeptideHit &first, const ProticPeptideHit &second) {
               return (first.key < second.key);
             });
@@ -623,10 +622,9 @@ ProticdbMl::writePeptideHit(QString xml_id,
       protic_peptide_hit.peptide_match.getPeptideEvidence()->getScanNumber()));
   qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
   _output_stream->writeAttribute(
-    "ms_run_id",
-    protic_peptide_hit.peptide_match.getPeptideEvidence()
-      ->getMsRunP()
-      ->getXmlId());
+    "ms_run_id", protic_peptide_hit.peptide_match.getPeptideEvidence()
+                   ->getMsRunP()
+                   ->getXmlId());
   _output_stream->writeAttribute("id", xml_id);
   _output_stream->writeAttribute(
     "exp_z",
@@ -746,8 +744,7 @@ ProticdbMl::writeMatchs(IdentificationGroup *p_identification)
       std::vector<const ProteinMatch *> protein_match_list =
         group_pair.second.get()->getProteinMatchList();
       // sort protein match by subgroup
-      std::sort(protein_match_list.begin(),
-                protein_match_list.end(),
+      std::sort(protein_match_list.begin(), protein_match_list.end(),
                 [](const ProteinMatch *a, const ProteinMatch *b) {
                   return a->getGrpProteinSp().get()->getSubGroupNumber() <
                          b->getGrpProteinSp().get()->getSubGroupNumber();
@@ -839,7 +836,8 @@ ProticdbMl::writeMatch(std::vector<const ProteinMatch *> &protein_match_sg_list)
           sample_name_list
             << peptide_match.getPeptideEvidence()->getMsRunP()->getSampleName();
         }
-      sample_name_list = sample_name_list.toSet().values();
+
+      sample_name_list.removeDuplicates();
       for(QString sample_name : sample_name_list)
         {
           _output_stream->writeStartElement("matchSample");
@@ -859,9 +857,8 @@ ProticdbMl::writeMatch(std::vector<const ProteinMatch *> &protein_match_sg_list)
               p_protein_match->getProteinXtpSp().get()->getAccession()));
           // proteinHit.setAttribute("score", "");
           _output_stream->writeAttribute(
-            "rank",
-            QString("%1").arg(
-              p_protein_match->getGrpProteinSp().get()->getRank()));
+            "rank", QString("%1").arg(
+                      p_protein_match->getGrpProteinSp().get()->getRank()));
 
           // //cvparam
           writeCvParam("PROTICdbO:0000284",
@@ -882,8 +879,7 @@ ProticdbMl::writeMatch(std::vector<const ProteinMatch *> &protein_match_sg_list)
           // id: PROTICdbO:0000335
           // name: X!TandemPipeline PAI
           writeCvParam("PROTICdbO:0000335",
-                       Utils::getXmlDouble(p_protein_match->getPAI()),
-                       "PAI");
+                       Utils::getXmlDouble(p_protein_match->getPAI()), "PAI");
 
           // [Term]
           // id: PROTICdbO:0000337
