@@ -431,10 +431,9 @@ Xpip::writeMsrunAlignmentGroup(const MsRunAlignmentGroupSp alignment_group,
 void
 Xpip::writeAlignmentGroupParameters(const MsRunAlignmentGroupSp alignment_group)
 {
-  ZivyParams zivy_params   = alignment_group->getZivyParams();
   QString masschroqml_path = alignment_group->getMassChroqmlPath();
   MasschroqFileParameters mcq_file_params =
-    alignment_group->getMassChroQFileParams();
+    *(_sp_project.get()->getMasschroqFileParametersSp().get());
 
   // Alignment parameters
   _output_stream->writeStartElement("alignment_params");
@@ -465,15 +464,20 @@ Xpip::writeAlignmentGroupParameters(const MsRunAlignmentGroupSp alignment_group)
     "xic_method",
     QString::number((std::int8_t)mcq_file_params.xic_extraction_method));
   _output_stream->writeAttribute(
-    "smoothing", QString::number(zivy_params._smoothing_half_window));
+    "smoothing",
+    QString::number(mcq_file_params.m_zivyParams._smoothing_half_window));
   _output_stream->writeAttribute(
-    "minmax_half", QString::number(zivy_params._minmax_half_window));
+    "minmax_half",
+    QString::number(mcq_file_params.m_zivyParams._minmax_half_window));
   _output_stream->writeAttribute(
-    "maxmin_half", QString::number(zivy_params._maxmin_half_window));
+    "maxmin_half",
+    QString::number(mcq_file_params.m_zivyParams._maxmin_half_window));
   _output_stream->writeAttribute(
-    "minmax_thre", QString::number(zivy_params._minmax_threshold));
+    "minmax_thre",
+    QString::number(mcq_file_params.m_zivyParams._minmax_threshold));
   _output_stream->writeAttribute(
-    "maxmin_thre", QString::number(zivy_params._maxmin_threshold));
+    "maxmin_thre",
+    QString::number(mcq_file_params.m_zivyParams._maxmin_threshold));
   _output_stream->writeEndElement();
 
   // Masschroq parameters
