@@ -30,8 +30,7 @@
  ******************************************************************************/
 
 
-#ifndef PROTEINSTORE_H
-#define PROTEINSTORE_H
+#pragma once
 
 #include "../core/proteinxtp.h"
 #include "types.h"
@@ -90,5 +89,3 @@ class ProteinStore
   /** \brief recognize contaminant accession */
   QRegExp _regexp_contaminant;
 };
-
-#endif // PROTEINSTORE_H
