@@ -232,8 +232,32 @@ enum class PtmMode : std::int8_t
  */
 enum class McqrLoadDataMode : std::int8_t
 {
-  basic     = 0, ///< mcq.read.masschroq
+  basic    = 0, ///< mcq.read.masschroq
   fraction = 1, ///< mcq.read.masschroq.fraction
   label    = 2, ///< mcq.read.masschroq.label
   both     = 3, ///<
 };
+
+
+/** \def McqrExperimentType spectral count, xic
+ *
+ */
+enum class McqrExperimentType : std::int8_t
+{
+  spectralCount = 0, ///< use xtpcpp data
+  xic           = 1, ///< use masschroq results
+};
+
+
+/** \def CondorJobStatus HTCondor job status
+ * */
+enum class CondorJobStatus : std::int8_t
+{
+  Unexpanded     = 0, ///< 0 Unexpanded U
+  Idle           = 1, ///< 1 Idle I
+  Running        = 2, ///< 2 Running R
+  Removed        = 3, ///< 3 Removed X
+  Completed      = 4, ///< 4 Completed C
+  Held           = 5, ///< 5 Held H
+  Submission_err = 6  ///< 6 Submission_err E
+};
