@@ -26,6 +26,7 @@
 #include <QProcess>
 #include <QDebug>
 #include <QFileInfo>
+#include <QSettings>
 
 const QUrl
 Utils::getOlsUrl(QString psimod_accession)
@@ -318,8 +319,12 @@ Utils::checkXtandemVersion(const QString &tandem_bin_path)
 
   if(!xt_process->waitForStarted())
     {
-      throw pappso::PappsoException(
-        QObject::tr("X!Tandem process failed to start"));
+      QString err = QObject::tr("Could not start X!Tandem process "
+                                "'%1' with arguments '%2': %3")
+                      .arg(tandem_bin_path)
+                      .arg(arguments.join(QStringLiteral(" ")))
+                      .arg(xt_process->errorString());
+      throw pappso::PappsoException(err);
     }
 
   while(xt_process->waitForReadyRead(1000))
@@ -415,8 +420,12 @@ Utils::checkMassChroQVersion(const QString &masschroq_bin_path)
 
   if(!mcq_process->waitForStarted())
     {
-      throw pappso::PappsoException(
-        QObject::tr("MassChroQ process failed to start"));
+      QString err = QObject::tr("Could not start MassChroQ process "
+                                "'%1' with arguments '%2': %3")
+                      .arg(masschroq_bin_path)
+                      .arg(arguments.join(QStringLiteral(" ")))
+                      .arg(mcq_process->errorString());
+      throw pappso::PappsoException(err);
     }
 
   while(mcq_process->waitForReadyRead(1000))
@@ -466,13 +475,20 @@ Utils::checkRVersion(const QString r_version)
 
   arguments << "--version";
 
-  QProcess *r_process = new QProcess();
+  QSettings settings;
+  QString r_binary_path = settings.value("path/r_binary", "R").toString();
+  QProcess *r_process   = new QProcess();
 
-  r_process->start("R", arguments);
+  r_process->start(r_binary_path, arguments);
 
   if(!r_process->waitForStarted())
     {
-      throw pappso::PappsoException(QObject::tr("R process failed to start"));
+      QString err = QObject::tr("Could not start R process "
+                                "'%1' with arguments '%2': %3")
+                      .arg(r_binary_path)
+                      .arg(arguments.join(QStringLiteral(" ")))
+                      .arg(r_process->errorString());
+      throw pappso::PappsoException(err);
     }
 
   while(r_process->waitForReadyRead(1000))
